pub enum AccountAttributesClearingStatus {
O,
P,
N,
A,
R,
C,
}Expand description
Status of the account with respect to clearing at IB. O is open, P pending, N new, A abandoned, C closed, R rejected.
Variants