pub enum EnumerationType {
Show 15 variants
ExchangeBundles,
BusinessAndOccupation,
EmployeeTrack,
FinInfoRanges,
Acats,
Aton,
MarketData,
EddAvt,
ProhibitedCountry,
EmployeePlans,
Questionnaires,
SecurityQuestions,
QuizQuestions,
WireInstructions,
ProductCountryBundles,
}Expand description
- exchange-bundles - query most up to date list of exchange-bundles for tradingPermissions
- business-and-occupation - list of occupation and employerBusiness for employmentDetails
- employee-track - query most up to date companyId for account. For affiliation details, if company has an existing IBKR Employee Track account
- fin-info-ranges - query most up to date range IDs by currency for annualNetIncome, netWorth, liquidNetWorth
- acats - query most up to date values for brokerId and brokerName. Used if funding via US ACATS extPositionsTransfers
- aton - query most up to date values for brokerId and brokerName. Used if funding via US ACATS extPositionsTransfers
- market-data - query most up to date values for brokerId and brokerName. Used if funding via ATON Canada extPositionsTransfers
- edd-avt - query questions associated with EDD (Enhanced Due Diligence) or AVT (Additional Verification) tasks assigned to an account
- prohibited-country - view list of prohibited countries. Applicants that reside in prohibited country are restricted from opening an account with IBKR. Error will be thrown IF legalResidenceCountry, OR country (included within Residence, mailingAddress and employerAddress, taxResidency node) is a prohibited country
- employee-plans - view EPA that are linked to master account (applicable IF offering SEP IRA accounts)
- questionnaires - obtain list of questionnaires
- security-questions - obtain list of questions supported for IBKR security questions
- quiz-questions - obtain list of questions associated with IBKR knowledge assessment
- wire-instructions - obtain list of wire instructions
- product-country-bundles - obtain list of product country bundles
Variants
ExchangeBundles
BusinessAndOccupation
EmployeeTrack
FinInfoRanges
Acats
Aton
MarketData
EddAvt
ProhibitedCountry
EmployeePlans
Questionnaires
SecurityQuestions
QuizQuestions
WireInstructions
ProductCountryBundles