pub enum GetAccountOwnersResponse {
Ok(SignatureAndOwners),
BadRequest,
Unauthorized,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getAccountOwners
Variants
Ok(SignatureAndOwners)
200: An object containing valid accounts and the account properties regarding trading access. This endpoint is also used to confirm account validation.
BadRequest
400: bad request; accountId is empty
401: Invalid or expired access token
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response