pub enum GetAccountSummaryResponse {
Ok(AccountSummaryResponse),
BadRequest,
Unauthorized,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getAccountSummary
Variants
Ok(AccountSummaryResponse)
200: Provides a general overview of the account details such as balance values.
BadRequest
400: bad request; passed input cannot pass initial validation and detected right away
401: Invalid or expired access token
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response