pub enum GetBrokerageAccountsResponse {
Ok(UserAccountsResponse),
Unauthorized,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getBrokerageAccounts
Variants
Ok(UserAccountsResponse)
200: An object containing valid accounts and the account properties regarding trading access. This endpoint is also used to confirm account validation.
401: Invalid or expired access token
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response