pub enum GetCurrencyPairsResponse {
Ok(CurrencyPairs),
BadRequest,
Unauthorized,
InternalServerError,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getCurrencyPairs
Variants
Ok(CurrencyPairs)
200: Returns a list of valid forex pairs for the given currency. The currency can apply as both the target or base currency.
BadRequest
400: Invalid input format or missing required fields
401: Invalid or expired access token
InternalServerError
500: internal server error, returned when incoming request cannot be processed. It can sometimes include subset of bad requests. For example, wrong accountId passed and it can only be detected later in handling request. Error contains reason of the problem.
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response