pub enum GetForecastScheduleResponse {
Ok(ForecastSchedulesResponse),
Unauthorized,
InternalServerError,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getForecastSchedule
Variants
Ok(ForecastSchedulesResponse)
200: Returns the liquid and extended trading hours of the coming and prior trading days.
401: Invalid or expired access token
InternalServerError
500: internal server error, returned when incoming request cannot be processed. It can sometimes include subset of bad requests. For example, wrong accountId passed and it can only be detected later in handling request. Error contains reason of the problem.
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response