pub enum GetFundSummaryResponse {
Ok(AvailableFundsResponse),
BadRequest,
Unauthorized,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getFundSummary
Variants
Ok(AvailableFundsResponse)
200: Indicates a successful return of available funds.
BadRequest
400: bad request; passed input cannot pass initial validation and detected right away
401: Invalid or expired access token
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response