pub enum GetGwApiV1EnumerationsComplexAssetTransferResponse {
Ok(GetBrokerListResponse),
BadRequest,
InternalServerError,
Unknown,
}Expand description
Response types for get_gw_api_v1_enumerations_complex_asset_transfer
Variants
Ok(GetBrokerListResponse)
200: Returns list of brokers supported for given asset type
BadRequest
400: Returns a Problem detail instance representing a not found request.
InternalServerError
500: Unable to process request due to an Internal Error. Please try again later.
Unknown
default: Unknown response