pub enum GetGwApiV1InstructionSetsInstructionsetidResponse {
Ok(BulkMultiStatusResponse),
NotFound,
InternalServerError,
Unknown,
}Expand description
Response types for get_gw_api_v1_instruction_sets_instructionsetid
Variants
Ok(BulkMultiStatusResponse)
200: Returns the status multiple instructions.
NotFound
404: Returns a Problem detail instance representing a not found request.
InternalServerError
500: Unable to process request due to an Internal Error. Please try again later.
Unknown
default: Unknown response