pub enum GetGwApiV1InstructionsInstructionidResponse {
Ok(Instruction200Response),
NotFound,
InternalServerError,
Unknown,
}Expand description
Response types for get_gw_api_v1_instructions_instructionid
Variants
Ok(Instruction200Response)
200: Returns the status of an instruction.
NotFound
404: Returns a Problem detail instance representing a not found request.
InternalServerError
500: Unable to process request due to an Internal Error. Please try again later.
Unknown
default: Unknown response