pub enum GetGwApiV1TradeConfirmationsAvailableResponse {
Ok(GetAvailableTradeConfirmationDatesResponse),
BadRequest,
Unauthorized,
PaymentRequired,
Forbidden,
InternalServerError,
Unknown,
}Expand description
Response types for get_gw_api_v1_trade_confirmations_available
Variants
Ok(GetAvailableTradeConfirmationDatesResponse)
200: Returns a JSON object containing the available user-traded dates.
BadRequest
400: Returns a Problem detail instance representing a bad request.
401: Returns a Problem detail instance representing an unauthorized request.
PaymentRequired
402: Returns a Problem detail instance representing an unauthorized request.
Forbidden
403: Returns a Problem detail instance representing a forbidden request.
InternalServerError
500: Returns a Problem detail instance representing an internal server error.
Unknown
default: Unknown response