pub enum History200Response {
BidAsk(IserverHistoryBidAskResponse),
Last(IserverHistoryLastResponse),
Midpoint(IserverHistoryMidpointResponse),
}Variants
BidAsk(IserverHistoryBidAskResponse)
Object containing the requested historical data and related metadata.
Last(IserverHistoryLastResponse)
Object containing the requested historical data and related metadata.
Midpoint(IserverHistoryMidpointResponse)
Object containing the requested historical data and related metadata.
Implementations