MessageIdRequestBodyMessageId

Enum MessageIdRequestBodyMessageId 

pub enum MessageIdRequestBodyMessageId {
Show 25 variants O163, O354, O382, O383, O403, O451, O2136, O2137, O2165, O10082, O10138, O10151, O10152, O10153, O10164, O10223, O10288, O10331, O10332, O10333, O10334, O10335, O10336, P6, P12,
}
A warning message to be pre-approved.

  • o163 - The following order exceeds the price percentage limit
  • o354 - “”“You are submitting an order without market data. We strongly recommend against this as it may result in erroneous and unexpected trades. Are you sure you want to submit this order?”“”
  • o382 - The following value exceeds the tick size limit
  • o383 - “”“The following order "“BUY 650 AAPL NASDAQ.NMS"” size exceeds the Size Limit of 500. Are you sure you want to submit this order?“”“
  • o403 - “”“This order will most likely trigger and fill immediately. Are you sure you want to submit this order?”“”
  • o451 - “”“The following order "“BUY 650 AAPL NASDAQ.NMS"” value estimate of 124,995.00 USD exceeds the Total Value Limit of 100,000 USD. Are you sure you want to submit this order?“”“
  • o2136 - Mixed allocation order warning
  • o2137 - Cross side order warning
  • o2165 - Warns that instrument does not support trading in fractions outside regular trading hours
  • o10082 - Called Bond warning
  • o10138 - The following order size modification exceeds the size modification limit.
  • o10151 - Warns about risks with Market Orders
  • o10152 - Warns about risks associated with stop orders once they become active
  • o10153 -

    Confirm Mandatory Cap Price

    To avoid trading at a price that is not consistent with a fair and orderly market, IB may set a cap (for a buy order) or sell order). THIS MAY CAUSE AN ORDER THAT WOULD OTHERWISE BE MARKETABLE TO NOT BE TRADED.
  • o10164 - “”“Traders are responsible for understanding cash quantity details, which are provided on a best efforts basis only.”“”
  • o10223 - “”“

    Cash Quantity Order Confirmation

    Orders that express size using a monetary value (cash quantity) are provided on a non-guaranteed basis. The system simulates the order by cancelling it once the specified amount is spent (for buy orders) or collected (for sell orders). In addition to the monetary value, the order uses a maximum size that is calculated using the Cash Quantity Estimate Factor, which you can modify in Presets.”“”
  • o10288 - Warns about risks associated with market orders for Crypto
  • o10331 - “”“You are about to submit a stop order. Please be aware of the various stop order types available and the risks associated with each one. Are you sure you want to submit this order?”“”
  • o10332 - OSL Digital Securities LTD Crypto Order Warning
  • o10333 - Option Exercise at the Money warning
  • o10334 - Warns that order will be placed into current omnibus account instead of currently selected global account.
  • o10335 - Serves internal Rapid Entry window.
  • o10336 - This security has limited liquidity. If you choose to trade this security, there is a heightened risk that you may not be able to close your position at the time you wish, at a price you wish, and/or without incurring a loss. Confirm that you understand the risks of trading illiquid securities.
  • `Are you sure you want to submit this order?
  • p6 - This order will be distributed over multiple accounts. We strongly suggest you familiarize yourself with our allocation facilities before submitting orders.
  • p12 - “If your order is not immediately executable, our systems may, depending on market conditions, reject your order if its limit price is more than the allowed amount away from the reference price at that time. If this happens, you will not receive a fill. This is a control designed to ensure that we comply with our regulatory obligations to avoid submitting disruptive orders to the marketplace.
    Use the Price Management Algo?”

Variants



O163



O354



O382



O383



O403



O451



O2136



O2137



O2165



O10082



O10138



O10151



O10152



O10153



O10164



O10223



O10288



O10331



O10332



O10333



O10334



O10335



O10336



P6



P12