pub enum Order200Response {
OrderSubmitSuccess(OrderSubmitSuccess),
OrderSubmitError(OrderSubmitError),
OrderReplyMessage(OrderReplyMessage),
AdvancedOrderReject(AdvancedOrderReject),
}Variants
OrderSubmitSuccess(OrderSubmitSuccess)
A successful submission of one or more order tickets.
OrderSubmitError(OrderSubmitError)
Indicates that the order reply message or submission was not accepted.
OrderReplyMessage(OrderReplyMessage)
An array containing objects that each deliver the order reply messages emitted against one order ticket in the submission request’s array. Indicies of the order reply message objects in this array correspond to the indicies of the order tickets in the submission request’s array.
AdvancedOrderReject(AdvancedOrderReject)
Relates a message generated in response to the rejection of the submitted order ticket. In some cases, it may also present a mechanism to resubmit the same order following a prompted decision.
Implementations
Sourceimpl Order200Response
impl Order200Response
Sourcepub fn order_submit_error(error: Option<String>) -> Self
pub fn order_submit_error(error: Option<String>) -> Self
Indicates that the order reply message or submission was not accepted.
Sourcepub fn advanced_order_reject() -> Self
pub fn advanced_order_reject() -> Self
Relates a message generated in response to the rejection of the submitted order ticket. In some cases, it may also present a mechanism to resubmit the same order following a prompted decision.