pub enum Order200Response2 {
CancelSuccess(OrderCancelSuccess),
SubmitError(OrderSubmitError),
}Variants
CancelSuccess(OrderCancelSuccess)
Acknowledges IB’s acceptance of the request to cancel the order. Does not report whether the cancellation can or will ultimately be enacted.
SubmitError(OrderSubmitError)
Indicates that the order reply message or submission was not accepted.
Implementations
Sourceimpl Order200Response2
impl Order200Response2
Sourcepub fn cancel_success() -> Self
pub fn cancel_success() -> Self
Acknowledges IB’s acceptance of the request to cancel the order. Does not report whether the cancellation can or will ultimately be enacted.
Sourcepub fn submit_error(error: Option<String>) -> Self
pub fn submit_error(error: Option<String>) -> Self
Indicates that the order reply message or submission was not accepted.