pub enum PerformanceRequestBodyPeriod {
T1d,
T7d,
Mtd,
T1m,
T3m,
T6m,
T12m,
Ytd,
}Expand description
Specify the period for which the account should be analyzed. Available period lengths:
1D- The last 24 hours.7D- The last 7 full days.MTD- Performance since the 1st of the month.1M- A full calendar month from the last full trade day.3M- 3 full calendar months from the last full trade day.6M- 6 full calendar months from the last full trade day.12M- 12 full calendar month from the last full trade day.YTD- Performance since January 1st.
Variants