pub enum PostGwApiV1BankInstructionsBulkResponse {
Accepted(AsynchronousInstructionSetResponse),
BadRequest,
InternalServerError,
Unknown,
}Expand description
Response types for post_gw_api_v1_bank_instructions_bulk
Variants
Accepted(AsynchronousInstructionSetResponse)
202: Accepts all instructions in Bulk request to create them asynchronously
BadRequest
400: Returns a Problem detail instance representing a bad request. Returned even if only one instruction in the bulk upload has syntactical errors.
InternalServerError
500: Unable to process request due to an Internal Error. Please try again later.
Unknown
default: Unknown response