pub enum PostGwApiV1BankInstructionsResponse {
Accepted(AsynchronousInstructionResponse),
BadRequest,
Forbidden,
UnprocessableEntity,
InternalServerError,
Unknown,
}Expand description
Response types for post_gw_api_v1_bank_instructions
Variants
Accepted(AsynchronousInstructionResponse)
202: Accepts request to create a new instruction asynchronously
BadRequest
400: Returns a Problem detail instance representing a bad request.
Forbidden
403: Returns a Problem detail instance representing a forbidden request.
UnprocessableEntity
422: Returns a Problem detail instance representing a business error.
InternalServerError
500: Returns a Problem detail instance representing an internal server error.
Unknown
default: Unknown response