pub enum PostGwApiV1SsoBrowserSessionsResponse {
Ok(CreateBrowserSessionResponse),
BadRequest,
Unauthorized,
Forbidden,
InternalServerError,
Unknown,
}Expand description
Response types for post_gw_api_v1_sso_browser_sessions
Variants
Ok(CreateBrowserSessionResponse)
200: Create a Single Sign On (SSO) to access the IBKR hosted portal (White Branded).
BadRequest
400: Returns a Problem detail instance representing a bad request.
401: Returns a Problem detail instance representing an unauthorized request.
Forbidden
403: Returns a Problem detail instance representing a forbidden request.
InternalServerError
500: Returns a Problem detail instance representing an internal server error.
Unknown
default: Unknown response