pub enum PostGwApiV1SsoSessionsResponse {
Ok(CreateSessionResponse),
BadRequest,
Unauthorized,
Forbidden,
InternalServerError,
Unknown,
}Expand description
Response types for post_gw_api_v1_sso_sessions
Variants
Ok(CreateSessionResponse)
200: Returns a JSON object containing a reference to the newly created SSO session.
BadRequest
400: Returns a Problem detail instance representing a bad request.
401: Returns a Problem detail instance representing an unauthorized request.
Forbidden
403: Returns a Problem detail instance representing a forbidden request.
InternalServerError
500: Returns a Problem detail instance representing an internal server error.
Unknown
default: Unknown response