pub enum SetActiveAccountResponse {
Ok(SetAccountResponse),
Unauthorized,
InternalServerError,
ServiceUnavailable,
Unknown,
}Expand description
Response types for setActiveAccount
Variants
Ok(SetAccountResponse)
200: Validates the account swapped to.
401: Invalid or expired access token
InternalServerError
500: Internal Server Error. Unable to process request if incoming values are not valid. For example accountId is not correct
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response