SubmitModelOrdersResponse

Enum SubmitModelOrdersResponse 

pub enum SubmitModelOrdersResponse {
    Ok(Transfer200Response),
    Unauthorized,
    InternalServerError,
    ServiceUnavailable,
    Unknown,
}
Response types for submitModelOrders

Variants



Ok(Transfer200Response)

200: Successfully transmit all orders.



Unauthorized

401: Invalid or expired access token



InternalServerError

500: internal server error, returned when incoming request cannot be processed. It can sometimes include subset of bad requests. For example, wrong accountId passed and it can only be detected later in handling request. Error contains reason of the problem.



ServiceUnavailable

503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned



Unknown

default: Unknown response