pub struct AccessToken200Response {
pub is_true: Option<bool>,
pub oauth_token: Option<String>,
pub oauth_token_secret: Option<String>,
}Fields
is_true: Option<bool>Indicates whether the authorizing username is paper or not.
oauth_token: Option<String>Permanent OAuth access token for the consumer with respect to the authorizing username. 20 character hex value.
oauth_token_secret: Option<String>OAuth token secret value. Base64-encoded string.