pub struct AccountAttributesParent {
pub account_id: Option<String>,
pub is_mchild: Option<bool>,
pub is_mparent: Option<bool>,
pub is_multiplex: Option<bool>,
pub mmc: Option<Vec<Value>>,
}Expand description
Describes account relations in partitioned or multiplexed (segemented) account structures.
Fields
account_id: Option<String>Account ID of the parent account in a multiplex account structure.
is_mchild: Option<bool>Indicates that the given account is a multiplex child account.
is_mparent: Option<bool>Indicates that the given account is itself a multiplex parent account.
is_multiplex: Option<bool>Indicates that the account is a multiplex account.
mmc: Option<Vec<Value>>Money manager client.