pub struct ActivateAlertRequest {
pub path: ActivateAlertRequestPath,
pub body: AlertActivationRequest,
}Expand description
Activate or Deactivate existing alerts created for this account. This does not delete alerts, but disables notifications until reactivated.
Fields
path: ActivateAlertRequestPathbody: AlertActivationRequestImplementations
Sourceimpl ActivateAlertRequest
impl ActivateAlertRequest
Sourcepub async fn parse_response(req: Response) -> Result<ActivateAlertResponse>
pub async fn parse_response(req: Response) -> Result<ActivateAlertResponse>
Parse the HTTP response into the response enum.