pub struct AdvancedOrderReject {
pub dismissable: Option<Vec<Value>>,
pub message_id: Option<String>,
pub options: Option<Vec<String>>,
pub order_id: Option<i32>,
pub prompt: Option<bool>,
pub req_id: Option<String>,
pub text: Option<String>,
pub type: Option<String>,
}Expand description
Relates a message generated in response to the rejection of the submitted order ticket. In some cases, it may also present a mechanism to resubmit the same order following a prompted decision.
Fields
dismissable: Option<Vec<Value>>Indicates whether this prompt is dismissable.
message_id: Option<String>IB internal identifier for the nature or category of the returned message.
options: Option<Vec<String>>Choices available to the client in response to the rejection message.
order_id: Option<i32>The order ID assigned by IB to the rejected order ticket.
prompt: Option<bool>Indicates that the message is a prompt offering a set of decisions, one or more of which may permit the rejected order to be resubmitted.
req_id: Option<String>IB’s internal identifier assigned to the returned message.
text: Option<String>Human-readable text of the messages emitted by IB in response to order submission.
type: Option<String>The specific type of message returned.