pub struct AlertCreationRequest {
pub alert_message: String,
pub alert_name: String,
pub alert_repeatable: AlertActivationRequestAlertActive,
pub conditions: Vec<AlertCreationRequestCondition>,
pub email: Option<String>,
pub expire_time: Option<String>,
pub i_twsorders_only: Option<i32>,
pub order_id: Option<i64>,
pub outside_rth: AlertActivationRequestAlertActive,
pub send_message: Option<AlertActivationRequestAlertActive>,
pub show_popup: Option<i32>,
pub tif: AlertCreationRequestTif,
}Fields
alert_message: StringAlert message which will be sent
alert_name: StringAlert name.
alert_repeatable: AlertActivationRequestAlertActiveBoolean number (0, 1) signifies if an alert can be triggered more than once. A value of ‘1’ is required for MTA alerts
conditions: Vec<AlertCreationRequestCondition>Container for all conditions applied for an alert to trigger.
email: Option<String>Email address you want to send email alerts to
expire_time: Option<String>Used with a tif of “GTD” only. Signifies time when the alert should terminate if no alert is triggered.
i_twsorders_only: Option<i32>allow (0) or disallow (1) alerts to trigger alerts through the mobile app
order_id: Option<i64>optional; used in case of modification and represent Alert Id
outside_rth: AlertActivationRequestAlertActiveAllow (1) or disallow (0) the alert to be triggered outside of regular trading hours
send_message: Option<AlertActivationRequestAlertActive>allow (1) or disallow (0) alerts to trigger email messages
show_popup: Option<i32>allow (1) or disallow (0) alerts to trigger TWS Pop-up messages
tif: AlertCreationRequestTifTime in Force duration of alert.