pub struct AlertDetails {Show 26 fields
pub account: Option<String>,
pub alert_name: Option<String>,
pub alert_active: Option<AlertActivationRequestAlertActive>,
pub alert_default_type: Option<i32>,
pub alert_email: Option<String>,
pub alert_message: Option<String>,
pub alert_mta_currency: Option<String>,
pub alert_mta_defaults: Option<String>,
pub alert_play_audio: Option<i32>,
pub alert_repeatable: Option<i32>,
pub alert_send_message: Option<i32>,
pub alert_show_popup: Option<i32>,
pub alert_triggered: Option<i32>,
pub bg_color: Option<String>,
pub condition_outside_rth: Option<i32>,
pub condition_size: Option<i32>,
pub conditions: Option<Vec<AlertCondition>>,
pub expire_time: Option<String>,
pub fg_color: Option<String>,
pub itws_orders_only: Option<i32>,
pub order_id: Option<i32>,
pub order_not_editable: Option<bool>,
pub order_status: Option<AlertDetailsOrderStatus>,
pub tif: Option<String>,
pub time_zone: Option<String>,
pub tool_id: Option<i32>,
}Expand description
details of the specified alert
Fields
account: Option<String>Requestor’s account ID
alert_name: Option<String>Human readable name of the alert.
alert_active: Option<AlertActivationRequestAlertActive>Returns if the alert is active [1] or disabled [0].
alert_default_type: Option<i32>Returns default type set for alerts. Configured in Client Portal.
alert_email: Option<String>Returns the designated email address for sendMessage functionality.
alert_message: Option<String>Returns the body content of what your alert will report once triggered
alert_mta_currency: Option<String>Returns currency set for MTA alerts. Only valid for alert type 8 & 9.
alert_mta_defaults: Option<String>Returns current MTA default values.
alert_play_audio: Option<i32>Returns whether or not the alert will play audio
alert_repeatable: Option<i32>Returns if the alert can be sent more than once.
alert_send_message: Option<i32>Returns whether or not the alert will send an email.
alert_show_popup: Option<i32>Returns whether or not the alert will trigger TWS Pop-up messages
alert_triggered: Option<i32>Returns whether or not the alert was triggered yet.
bg_color: Option<String>Background color. Not applicable to API.
condition_outside_rth: Option<i32>Returns whether or not the alert will trigger outside of regular trading hours.
condition_size: Option<i32>Returns the total number of conditions in the alert.
conditions: Option<Vec<AlertCondition>>Returns all conditions
expire_time: Option<String>Returns the UTC formatted date used in GTD orders.
fg_color: Option<String>Foreground color. Not applicable to API.
itws_orders_only: Option<i32>Returns whether or not the alert will trigger mobile notifications.
order_id: Option<i32>Alert’s tracking ID. Can be used for modifying or deleting alerts.
order_not_editable: Option<bool>Returns if the order can be edited.
order_status: Option<AlertDetailsOrderStatus>represent order statusAlways returns “Presubmitted”.
tif: Option<String>Time in Force effective for the Alert
time_zone: Option<String>Returned for time-specific conditions.
tool_id: Option<i32>Tracking ID for MTA alerts only. Returns ‘null’ for standard alerts.