pub struct AllocationGroup {
pub accounts: Option<Vec<AllocationGroupAccount>>,
pub default_method: Option<AllocationMethod>,
pub name: Option<String>,
}Fields
accounts: Option<Vec<AllocationGroupAccount>>Contains a series of objects depicting which accounts are involved and, for user-defined allocation methods, the distribution value for each sub-account.
default_method: Option<AllocationMethod>Interactive Brokers supports two forms of allocation methods. Allocation methods that have calculations completed by Interactive Brokers, and a set of allocation methods calculated by the user and then specified. IB-computed allocation methods:
A- Available EquityE- EqualN- Net Liquidation Value
User-specified allocation methods:
C- Cash QuantityP- PercentageR- RatiosS- Shares
name: Option<String>Name used to refer to your allocation group. This will be used while placing orders.