pub struct AvailableFundsResponseSecurities {
pub lk_ahd_avlbl_fnds: Option<String>,
pub lk_ahd_excss_lqdty: Option<String>,
pub prdctd_pst_xpry_excss: Option<String>,
pub sma: Option<String>,
pub current_available: Option<String>,
pub current_excess: Option<String>,
pub leverage: Option<String>,
pub overnight_available: Option<String>,
pub overnight_excess: Option<String>,
}Expand description
Contains an overview of Security specific fund values.
Fields
lk_ahd_avlbl_fnds: Option<String>This value reflects your available funds at the next margin change.
lk_ahd_excss_lqdty: Option<String>Securities- Equity with loan value. Look ahead maintenance margin.Commodities- Net Liquidation value. Look ahead maintenance margin.
prdctd_pst_xpry_excss: Option<String>Displays predicted post-expiration account value.
sma: Option<String>current_available: Option<String>Describes currently avialable funds in your account for trading.
current_excess: Option<String>Describes total value of the account.
leverage: Option<String>Describes the total combined leverage.
overnight_available: Option<String>Describes available funds for overnight trading.
overnight_excess: Option<String>Overnight refers to the window of time after the local market trading day is closed.
Securities- Equivalent to regular trading hours.Commodities- Commodities Net Liquidation value. Overnight Maintenance margin.