pub struct AvailableFundsResponseTotal {
pub lk_ahd_avlbl_fnds: Option<String>,
pub lk_ahd_excss_lqdty: Option<String>,
pub lk_ahd_nxt_chng: Option<String>,
pub prdctd_pst_xpry_excss: Option<String>,
pub buying_power: Option<String>,
pub current_available: Option<String>,
pub current_excess: Option<String>,
pub day_trades_left: Option<String>,
pub leverage: Option<String>,
pub overnight_available: Option<String>,
pub overnight_excess: Option<String>,
}Expand description
total values
Fields
lk_ahd_avlbl_fnds: Option<String>This value reflects your available funds at the next margin change.
lk_ahd_excss_lqdty: Option<String>Securities- Equity with loan value. Look ahead maintenance margin.Commodities- Net Liquidation value. Look ahead maintenance margin.
lk_ahd_nxt_chng: Option<String>Describes when the next ‘Look Ahead’ calculation will take place.
prdctd_pst_xpry_excss: Option<String>Displays predicted post-expiration account value.
buying_power: Option<String>Describes the total buying power of the account including existing balance with margin.
current_available: Option<String>Describes currently avialable funds in your account for trading.
current_excess: Option<String>Describes total value of the account.
day_trades_left: Option<String>Describes the number of trades remaining before flagging the Pattern Day Trader status. “Unlimited” is used for existing Pattern Day Traders.
leverage: Option<String>Describes the total combined leverage.
overnight_available: Option<String>Describes available funds for overnight trading.
overnight_excess: Option<String>Overnight refers to the window of time after the local market trading day is closed.
Securities- Equivalent to regular trading hours.Commodities- Commodities Net Liquidation value. Overnight Maintenance margin.