pub struct BondFiltersResponseFilter {
pub column_id: Option<i32>,
pub display_text: Option<BondFiltersResponseFilterDisplayText>,
pub options: Option<Vec<BondFiltersResponseFilterOption>>,
}Fields
column_id: Option<i32>Used for user interfaces. Internal use only.
display_text: Option<BondFiltersResponseFilterDisplayText>An identifier used to document returned options/values. This can be thought of as a key value.
options: Option<Vec<BondFiltersResponseFilterOption>>Contains all objects with values corresponding to the parent displayText key.