pub struct BondFiltersResponseFilterOption {
pub text: Option<String>,
pub value: String,
}Fields
text: Option<String>In some instances, a text value will be returned, which indicates the standardized value format such as plaintext dates, rather than solely numerical values.
value: StringReturns value directly correlating to the displayText key. This may include exchange, maturity date, issue date, coupon, or currency.