BrokerageSessionStatus

Struct BrokerageSessionStatus 

pub struct BrokerageSessionStatus {
    pub mac: Option<String>,
    pub authenticated: Option<bool>,
    pub competing: Option<bool>,
    pub connected: Option<bool>,
    pub established: Option<bool>,
    pub fail: Option<String>,
    pub hardware_info: Option<String>,
    pub message: Option<String>,
    pub server_info: Option<BrokerageSessionStatusServerInfo>,
}

Fields

mac: Option<String>

Device MAC information.

authenticated: Option<bool>

Returns whether your brokerage session is authenticated or not.

competing: Option<bool>

Returns whether you have a competing brokerage session in another connection.

connected: Option<bool>

Returns whether you are connected to the gateway or not.

established: Option<bool>

Returns whether your brokerage session is fully established and ready to handle requests. Set to true when the login message is received from underlying brokerage infrastructure, indicating authentication is complete and account information is loaded.

fail: Option<String>

Returns the reason for failing to retrieve authentication status.

hardware_info: Option<String>

Client Portal use only.

message: Option<String>

A message about your authenticate status if any.

server_info: Option<BrokerageSessionStatusServerInfo>