pub struct CancelOpenOrderRequestQuery {
pub ext_operator: Option<String>,
pub manual_indicator: Option<bool>,
pub manual_cancel_time: Option<i32>,
}Fields
ext_operator: Option<String>ExtOperator is used to identify external operator.
manual_indicator: Option<bool>For all orders for US Futures products, clients must submit this flag to indicate whether the order was originated manually (by a natural person) or automatically (by an automated trading system transmitting orders without human intervention). Submit a True value to indicate a manually originated order, and submit a False value to indicate an automated order. Orders for USFUT products that do not include this field will be rejected.
manual_cancel_time: Option<i32>Time of manual cancel.
- Example:
Some(1_799_796_559i32)