pub struct DepositFundsInstructionOpenBankingPlaidOptions {
pub completion_redirect_uri: Option<String>,
pub is_mobile_app: Option<bool>,
pub link_display_name: Option<String>,
}Fields
completion_redirect_uri: Option<String>This should be a URI with a custom scheme and this can be any value you’d like, as long as it isn’t a reserved one such as http or tel. By convention, it’s often one associated with the name of your application.
- Example:
Some("wonderwallet://hosted-link-complete".to_string())
is_mobile_app: Option<bool>link_display_name: Option<String>Client Name displayed on Plaid Link UI
- Example:
Some("WonderWallet".to_string())