pub struct Detail200ResponseAccountInfoList {
pub account: Option<String>,
pub account_imbalance: Option<String>,
pub alias: Option<String>,
pub base_ccy_account: Option<String>,
pub cost_basis: Option<String>,
pub exchange_rate: Option<f64>,
pub nlv: Option<String>,
pub num_instruments_outside_range: Option<i32>,
pub unrealized_pn_l: Option<String>,
}Fields
account: Option<String>Account identifier.
account_imbalance: Option<String>Account’s imbalance from the target allocation.
alias: Option<String>Account alias.
base_ccy_account: Option<String>Base currency of the account.
cost_basis: Option<String>Cost basis.
exchange_rate: Option<f64>Exchange rate of the account base currency to the model base currency.
nlv: Option<String>The net liquidation value of the instrument.
num_instruments_outside_range: Option<i32>The number of instruments held by the account outside of the alloted range from the presets.
unrealized_pn_l: Option<String>The unrealized profit and loss of the model within the account.