pub struct DynAccountSearchResponseMatchedAccount {
pub account_id: Option<String>,
pub alias: Option<String>,
pub allocation_id: Option<String>,
}Fields
account_id: Option<String>Returns a matching account ID that corresponds to the matching value.
alias: Option<String>Returns the corresponding alias or alternative name for the specific account ID. May be a duplicate of the accountId value in most cases.
allocation_id: Option<String>Returns the allocation identifier used internally for the account.