pub struct Features {
pub symbol: Option<Vec<FeaturesSymbol>>,
}Fields
symbol: Option<Vec<FeaturesSymbol>>Displayed as the string of your symbol Contains a series of objects for each symbol that matches the requested.