pub struct FeaturesSymbol {
pub conid: Option<i32>,
pub expiration_date: Option<i32>,
pub long_futures_cut_off: Option<i32>,
pub ltd: Option<i32>,
pub short_futures_cut_off: Option<i32>,
pub symbol: Option<String>,
pub underlying_conid: Option<i32>,
}Fields
conid: Option<i32>Contract identifier for the specific symbol
expiration_date: Option<i32>Expiration date of the specific future contract.
long_futures_cut_off: Option<i32>Represents the final day for contract rollover for long futures.
ltd: Option<i32>Last trade date of the future contract.
short_futures_cut_off: Option<i32>Represents the final day for contract rollover for shorted futures.
symbol: Option<String>The requested symbol value.
underlying_conid: Option<i32>Contract identifier for the future’s underlying contract.