pub struct ForecastMarketResponse {
pub contracts: Option<Vec<ForecastMarketResponseContract>>,
pub exchange: Option<String>,
pub exclude_historical_data: Option<bool>,
pub logo_category: Option<String>,
pub market_name: Option<String>,
pub payout: Option<f64>,
pub symbol: Option<String>,
}Fields
contracts: Option<Vec<ForecastMarketResponseContract>>List of contracts matching the requested market.
exchange: Option<String>Exchange that was passed in request or determined internally.
exclude_historical_data: Option<bool>Indicates whether UI should or should not display underlying chart.
logo_category: Option<String>Logo category to use in logo service to retrieve image.
market_name: Option<String>Market contract identifier.
payout: Option<f64>Ratio of payout scaling.
symbol: Option<String>Market symbol.