pub struct GetAccountOwnersRequest {
pub path: GetAccountOwnersRequestPath,
}Expand description
Receive a list of all applicant names on the account and for which account and entity is represented.
Fields
path: GetAccountOwnersRequestPathImplementations
Sourceimpl GetAccountOwnersRequest
impl GetAccountOwnersRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetAccountOwnersResponse>
pub async fn parse_response(req: Response) -> Result<GetAccountOwnersResponse>
Parse the HTTP response into the response enum.