pub struct GetAllocatableSubaccountsRequest {}Expand description
Retrieves a list of all sub-accounts and returns their net liquidity and available equity for advisors to make decisions on what accounts should be allocated and how. This endpoint is only supported for Financial Advisors and IBroker Accounts.
Implementations
Sourceimpl GetAllocatableSubaccountsRequest
impl GetAllocatableSubaccountsRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetAllocatableSubaccountsResponse>
pub async fn parse_response( req: Response, ) -> Result<GetAllocatableSubaccountsResponse>
Parse the HTTP response into the response enum.