pub struct GetBrokerageAccountsRequest {}Expand description
Returns a list of accounts the user has trading access to, their respective aliases and the currently selected account. Note this endpoint must be called before modifying an order or querying open orders.
Implementations
Sourceimpl GetBrokerageAccountsRequest
impl GetBrokerageAccountsRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetBrokerageAccountsResponse>
pub async fn parse_response( req: Response, ) -> Result<GetBrokerageAccountsResponse>
Parse the HTTP response into the response enum.