pub struct GetComboPositionsRequest {
pub path: GetComboPositionsRequestPath,
pub query: GetComboPositionsRequestQuery,
}Expand description
Provides all positions held in the account acquired as a combination, including values such as ratios, size, and market value.
Fields
path: GetComboPositionsRequestPathquery: GetComboPositionsRequestQueryImplementations
Sourceimpl GetComboPositionsRequest
impl GetComboPositionsRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetComboPositionsResponse>
pub async fn parse_response(req: Response) -> Result<GetComboPositionsResponse>
Parse the HTTP response into the response enum.