pub struct GetContractInfoRequestQuery {
pub conid: Option<String>,
pub sectype: Option<Value>,
pub month: Option<Value>,
pub exchange: Option<Value>,
pub strike: Option<Value>,
pub right: Option<IndividualPositionPutOrCall>,
pub issuer_id: Option<String>,
pub filters: Option<Value>,
}Fields
conid: Option<String>Contract identifier of the underlying. May also pass the final derivative conid directly.
- Example:
Some("265598".to_string())
sectype: Option<Value>Security type of the requested contract of interest.
month: Option<Value>Expiration month for the given derivative.
exchange: Option<Value>Designate the exchange you wish to receive information for in relation to the contract.
strike: Option<Value>Set the strike price for the requested contract details
right: Option<IndividualPositionPutOrCall>Set the right for the given contract. * C - for Call options. * P - for Put options.
issuer_id: Option<String>Set the issuerId for the given bond issuer type.
- Example:
Some("e1234567".to_string())
filters: Option<Value>comma separted list of additional filters. Applicable when SecTyp is BOND