pub struct GetContractStrikesRequest {
pub query: GetContractStrikesRequestQuery,
}Expand description
Returns lists of valid strikes for options contracts on a given underlier, for all currently trading expirations. The /iserver/secdef/search endpoint must be called prior for the underlying. Otherwise empty arrays will return for “puts” and “calls”.
Fields
query: GetContractStrikesRequestQueryImplementations
Sourceimpl GetContractStrikesRequest
impl GetContractStrikesRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetContractStrikesResponse>
pub async fn parse_response(req: Response) -> Result<GetContractStrikesResponse>
Parse the HTTP response into the response enum.