pub struct GetContractSymbolsRequestQuery {
pub symbol: Option<String>,
pub sec_type: Option<GetContractSymbolsRequestQuerySecType>,
pub name: Option<bool>,
pub more: Option<bool>,
pub fund: Option<bool>,
pub fund_family_conid_ex: Option<String>,
pub pattern: Option<bool>,
pub referrer: Option<String>,
}Fields
symbol: Option<String>The ticker symbol, bond issuer type, or company name of the equity you are looking to trade.
- Example:
Some("AAPL".to_string())
sec_type: Option<GetContractSymbolsRequestQuerySecType>Available underlying security types:
STK- Represents an underlying as a Stock security type.IND- Represents an underlying as an Index security type.BOND- Represents an underlying as a Bond security type.
name: Option<bool>Denotes if the symbol value is the ticker symbol or part of the company’s name.
more: Option<bool>fund: Option<bool>fund search
fund_family_conid_ex: Option<String>pattern: Option<bool>pattern search
referrer: Option<String>Trait Implementations
Sourceimpl Clone for GetContractSymbolsRequestQuery
impl Clone for GetContractSymbolsRequestQuery
Sourcefn clone(&self) -> GetContractSymbolsRequestQuery
fn clone(&self) -> GetContractSymbolsRequestQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for GetContractSymbolsRequestQuery
impl PartialEq for GetContractSymbolsRequestQuery
Sourcefn eq(&self, other: &GetContractSymbolsRequestQuery) -> bool
fn eq(&self, other: &GetContractSymbolsRequestQuery) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetContractSymbolsRequestQuery