pub struct GetDynamicAccountsRequest {
pub path: GetDynamicAccountsRequestPath,
}Expand description
Returns a list of accounts matching a query pattern set in the request. Broker accounts configured with the DYNACCT property will not receive account information at login. Instead, they must dynamically query then set their account number. Customers without the DYNACCT property will receive a 503 error.
Fields
path: GetDynamicAccountsRequestPathImplementations
Sourceimpl GetDynamicAccountsRequest
impl GetDynamicAccountsRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetDynamicAccountsResponse>
pub async fn parse_response(req: Response) -> Result<GetDynamicAccountsResponse>
Parse the HTTP response into the response enum.