GetGwApiV1EnumerationsEnumerationtypeRequestQuery

Struct GetGwApiV1EnumerationsEnumerationtypeRequestQuery 

pub struct GetGwApiV1EnumerationsEnumerationtypeRequestQuery {
    pub type: Option<EnumerationType>,
    pub currency: Option<String>,
    pub ib_entity: Option<String>,
    pub md_status_non_pro: Option<String>,
    pub form_number: Option<String>,
    pub language: Option<GetGwApiV1EnumerationsEnumerationtypeRequestQueryLanguage>,
    pub account_id: Option<String>,
    pub user_name: Option<String>,
}

Fields

type: Option<EnumerationType>
  • exchange-bundles - query most up to date list of exchange-bundles for tradingPermissions
  • business-and-occupation - list of occupation and employerBusiness for employmentDetails
  • employee-track - query most up to date companyId for account. For affiliation details, if company has an existing IBKR Employee Track account
  • fin-info-ranges - query most up to date range IDs by currency for annualNetIncome, netWorth, liquidNetWorth
  • acats - query most up to date values for brokerId and brokerName. Used if funding via US ACATS extPositionsTransfers
  • aton - query most up to date values for brokerId and brokerName. Used if funding via US ACATS extPositionsTransfers
  • market-data - query most up to date values for brokerId and brokerName. Used if funding via ATON Canada extPositionsTransfers
  • edd-avt - query questions associated with EDD (Enhanced Due Diligence) or AVT (Additional Verification) tasks assigned to an account
  • prohibited-country - view list of prohibited countries. Applicants that reside in prohibited country are restricted from opening an account with IBKR. Error will be thrown IF legalResidenceCountry, OR country (included within Residence, mailingAddress and employerAddress, taxResidency node) is a prohibited country
  • employee-plans - view EPA that are linked to master account (applicable IF offering SEP IRA accounts)
  • questionnaires - obtain list of questionnaires
  • security-questions - obtain list of questions supported for IBKR security questions
  • quiz-questions - obtain list of questions associated with IBKR knowledge assessment
  • wire-instructions - obtain list of wire instructions
  • product-country-bundles - obtain list of product country bundles
currency: Option<String>ib_entity: Option<String>md_status_non_pro: Option<String>form_number: Option<String>language: Option<GetGwApiV1EnumerationsEnumerationtypeRequestQueryLanguage>account_id: Option<String>user_name: Option<String>