pub struct GetInvestedAccountsInModelRequest {
pub body: PositionRequestBody,
}Expand description
Request the list of all accounts already invested in the provided model and a summary of their investment.
Fields
body: PositionRequestBodyImplementations
Sourceimpl GetInvestedAccountsInModelRequest
impl GetInvestedAccountsInModelRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetInvestedAccountsInModelResponse>
pub async fn parse_response( req: Response, ) -> Result<GetInvestedAccountsInModelResponse>
Parse the HTTP response into the response enum.