pub struct GetInvestedAccountsSummaryAccountList {
pub account: Option<String>,
pub account_model_nlv: Option<String>,
pub account_other_models_nlv: Option<String>,
pub alias: Option<String>,
pub base_ccy_account: Option<String>,
pub base_ccy_account_precision: Option<String>,
pub cash_in_independent_nlv: Option<String>,
pub exchange_rate: Option<f64>,
pub nlv: Option<String>,
pub positions_in_independent_nlv: Option<String>,
}Fields
account: Option<String>Account identifier (account number)
account_model_nlv: Option<String>Net liquidation value for positions in the current model portfolio
account_other_models_nlv: Option<String>Net liquidation value for positions in other model portfolios
alias: Option<String>User-defined alias for the account (empty string if not set)
base_ccy_account: Option<String>Base currency for this account (ISO 4217 currency code)
base_ccy_account_precision: Option<String>Precision for the account base currency (decimal places)
cash_in_independent_nlv: Option<String>Individual cash net liquidation value in base currency
exchange_rate: Option<f64>Exchange rate from account base currency to master base currency
nlv: Option<String>Total net liquidation value (cash + positions) in base currency
positions_in_independent_nlv: Option<String>Individual position net liquidation value in base currency