pub struct GetManySubaccountsRequest {
pub query: GetManySubaccountsRequestQuery,
}Expand description
Used in tiered account structures (such as Financial Advisor and IBroker Accounts) to return a list of sub-accounts, paginated up to 20 accounts per page, for which the user can view position and account-related information. This endpoint must be called prior to calling other /portfolio endpoints for those sub-accounts. If you have less than 100 sub-accounts use /portfolio/subaccounts. To query a list of accounts the user can trade, see /iserver/accounts.
Fields
query: GetManySubaccountsRequestQueryImplementations
Sourceimpl GetManySubaccountsRequest
impl GetManySubaccountsRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetManySubaccountsResponse>
pub async fn parse_response(req: Response) -> Result<GetManySubaccountsResponse>
Parse the HTTP response into the response enum.