pub struct GetMdHistoryRequestQuery {
pub conid: i32,
pub period: String,
pub bar: String,
pub exchange: Option<String>,
pub outside_rth: Option<bool>,
pub start_time: Option<String>,
pub direction: Option<GetMdHistoryRequestQueryDirection>,
pub source: Option<String>,
}Fields
conid: i32IB contract ID of the requested instrument.
- Example:
265_598i32
period: StringA time duration away from startTime into the future to be divided into bars of the specified width. Supported Period Sizes
min- Minutesh- Hour(s)d- Day(s)w- Week(s)m- Month(s)y- Year(s)
- Example:
"6d".to_string()
bar: StringThe width of the bars into which the interval determined by period and startTime will be divided. It is not required that bar evenly divide period; partial bars can be returned. Supported Bar Sizes
S- Second(s)min- Minute(s)h- Hour(s)d- Day(s)w- Week(s)m- Month(s)
- Example:
"5min".to_string()
exchange: Option<String>Exchange (or SMART) from which data is requested.
- Example:
Some("NASDAQ".to_string())
outside_rth: Option<bool>Indicates whether data outside of regular trading hours should be included in response.
start_time: Option<String>A fixed UTC date-time reference point for the historical data request, from which the specified period extends. Format is YYYYMMDD-hh:mm:ss. If omitted, the current time is used, and direction must be omitted or 1.
- Example:
Some("20231018-16:00:00".to_string())
direction: Option<GetMdHistoryRequestQueryDirection>Indicates whether data should begin or end at the start time.
-1- Historical data will begin away from the start time, ending at the current time/startTime.1- Historical data begins at the start time, moving towards the current time. Only supported when startTime is included.
source: Option<String>The type of data to be returned in the historical bars. Supported Bar Sizes
Bid_Ask- The OHLC bid/ask values.Last- The OHLC trade values.Midpoint- The OHLC of the Bid-Ask midpoint.
- Example:
Some("Midpoint".to_string())