pub struct GetMtaDetailsRequest {}Expand description
Retrieve information about your MTA alert. Each login user only has one mobile trading assistant (MTA) alert with it’s own unique tool id that cannot be changed. MTA alerts can not be created or deleted, only modified. When modified a new order Id is generated.
Implementations
Sourceimpl GetMtaDetailsRequest
impl GetMtaDetailsRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetMtaDetailsResponse>
pub async fn parse_response(req: Response) -> Result<GetMtaDetailsResponse>
Parse the HTTP response into the response enum.