pub struct GetOpenOrdersRequestQuery {
pub filters: Option<GetOpenOrdersRequestQueryFilters>,
pub force: Option<bool>,
}Fields
filters: Option<GetOpenOrdersRequestQueryFilters>Filter results using a comma-separated list of Order Status values. Also accepts a value to sort results by time.
- Example:
Some("filled")
force: Option<bool>Instructs IB to clear cache of orders and obtain updated view from brokerage backend. Response will be an empty array.