pub struct GetPositionByConidRequestPath {
pub accountid: String,
pub conid: i32,
}Fields
accountid: StringAccount ID whose position in the given instrument is requested.
- Example:
"DU123456".to_string()
conid: i32Conid of the instrument whose position in the account is requested.
- Example:
265_598i32