pub struct GetTransactionsRequest {
pub body: TransactionRequestBody,
}Expand description
Transaction history for a given number of conids and accounts. Types of transactions include dividend payments, buy and sell transactions, transfers.
Fields
body: TransactionRequestBodyImplementations
Sourceimpl GetTransactionsRequest
impl GetTransactionsRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetTransactionsResponse>
pub async fn parse_response(req: Response) -> Result<GetTransactionsResponse>
Parse the HTTP response into the response enum.