pub struct GetUncachedPositionsRequest {
pub path: GetUncachedPositionsRequestPath,
pub query: GetUncachedPositionsRequestQuery,
}Expand description
Returns a list of positions for the given account. /portfolio/accounts or /portfolio/subaccounts must be called prior to this endpoint. This endpoint provides near-real time updates and removes caching otherwise found in the /portfolio/{accountId}/positions/{pageId} endpoint.
Fields
path: GetUncachedPositionsRequestPathquery: GetUncachedPositionsRequestQueryImplementations
Sourceimpl GetUncachedPositionsRequest
impl GetUncachedPositionsRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetUncachedPositionsResponse>
pub async fn parse_response( req: Response, ) -> Result<GetUncachedPositionsResponse>
Parse the HTTP response into the response enum.