pub struct GroupRequestBody2 {
pub accounts: Vec<GroupRequestBodyAccount>,
pub default_method: Option<AllocationMethod>,
pub name: String,
}Fields
accounts: Vec<GroupRequestBodyAccount>An array of accounts that should be held in the allocation group and, if using a User-specified allocaiton method, the value correlated to the allocation.
default_method: Option<AllocationMethod>Interactive Brokers supports two forms of allocation methods. Allocation methods that have calculations completed by Interactive Brokers, and a set of allocation methods calculated by the user and then specified. IB-computed allocation methods:
A- Available EquityE- EqualN- Net Liquidation Value
User-specified allocation methods:
C- Cash QuantityP- PercentageR- RatiosS- Shares
name: StringName used to refer to your allocation group. If prev_name is specified, this will become the new name of the group.
- Example:
"Group_1_NetLiq".to_string()