pub struct IndividualComboPosition {Show 20 fields
pub acct_id: Option<String>,
pub asset_class: Option<String>,
pub avg_cost: Option<f64>,
pub avg_price: Option<f64>,
pub con_exch_map: Option<Vec<Value>>,
pub conid: Option<i32>,
pub contract_desc: Option<String>,
pub currency: Option<String>,
pub exchs: Option<Value>,
pub exercise_style: Option<String>,
pub expiry: Option<String>,
pub mkt_price: Option<f64>,
pub mkt_value: Option<f64>,
pub multiplier: Option<f64>,
pub position: Option<f64>,
pub put_or_call: Option<IndividualComboPositionPutOrCall>,
pub realized_pnl: Option<f64>,
pub strike: Option<String>,
pub und_conid: Option<i32>,
pub unrealized_pnl: Option<f64>,
}Fields
acct_id: Option<String>IB accountId of an account with a position in the requested conid.
asset_class: Option<String>Asset class of the requested instrument.
avg_cost: Option<f64>The account’s average cost for its position.
avg_price: Option<f64>The account’s average price for its position.
con_exch_map: Option<Vec<Value>>conid: Option<i32>IB contract ID for the instrument.
contract_desc: Option<String>Human-readable description of the instrument.
currency: Option<String>Currency in which the instrument trades.
exchs: Option<Value>exercise_style: Option<String>Style of exercise for options.
expiry: Option<String>Expiration of instrument, if applicable.
mkt_price: Option<f64>Current market price of the instrument, in the instrument’s currency.
mkt_value: Option<f64>Current market value of the account’s position in the instrument, in the instrument’s currency.
multiplier: Option<f64>Instrument’s multiplier, if applicable.
position: Option<f64>Size of position in units of instrument.
put_or_call: Option<IndividualComboPositionPutOrCall>The right of an options contract, if applicable.
realized_pnl: Option<f64>Realized PnL for the instrument in the instrument’s currency.
strike: Option<String>Strike price, if applicable. Returned as string.
und_conid: Option<i32>Contract ID of underlying instrument, if applicable.
unrealized_pnl: Option<f64>Unrealized PnL for the instrument in the account.