pub struct InitializeSessionRequest {
pub body: BrokerageSessionInitRequest,
}Expand description
After retrieving the access token and subsequent Live Session Token, customers can initialize their brokerage session with the ssodh/init endpoint.
Fields
body: BrokerageSessionInitRequestImplementations
Sourceimpl InitializeSessionRequest
impl InitializeSessionRequest
Sourcepub async fn parse_response(req: Response) -> Result<InitializeSessionResponse>
pub async fn parse_response(req: Response) -> Result<InitializeSessionResponse>
Parse the HTTP response into the response enum.