pub struct InvalidatePositionCacheRequest {
pub path: InvalidatePositionCacheRequestPath,
}Expand description
Instructs IB to discard cached portfolio positions for a given account, so that the next request for positions delivers freshly obtained data.
Fields
path: InvalidatePositionCacheRequestPathImplementations
Sourceimpl InvalidatePositionCacheRequest
impl InvalidatePositionCacheRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<InvalidatePositionCacheResponse>
pub async fn parse_response( req: Response, ) -> Result<InvalidatePositionCacheResponse>
Parse the HTTP response into the response enum.