IserverHistoryLastResponse

Struct IserverHistoryLastResponse 

pub struct IserverHistoryLastResponse {
Show 23 fields pub bar_length: Option<i32>, pub chart_pan_start_time: Option<String>, pub data: Option<Vec<SingleHistoricalBarLast>>, pub direction: Option<i32>, pub high: Option<String>, pub low: Option<String>, pub md_availability: Option<String>, pub message_version: Option<i32>, pub mkt_data_delay: Option<i32>, pub negative_capable: Option<bool>, pub outside_rth: Option<bool>, pub points: Option<i32>, pub price_display_rule: Option<i32>, pub price_display_value: Option<String>, pub price_factor: Option<i32>, pub server_id: Option<String>, pub start_time: Option<String>, pub symbol: Option<String>, pub text: Option<String>, pub time_period: Option<String>, pub trading_day_duration: Option<i32>, pub travel_time: Option<i32>, pub volume_factor: Option<i32>,
}
Object containing the requested historical data and related metadata.

Fields

bar_length: Option<i32>

The client-specified bar width, represented in seconds.

chart_pan_start_time: Option<String>

Internal use. UTC datetime string used to center Client Portal charts. Format YYYYMMDD-hh:mm:ss.

data: Option<Vec<SingleHistoricalBarLast>>

Array containing OHLC bars for the requested period.

direction: Option<i32>

Indicates how the period is applied in relation to the startTime. Value will always be -1, indicating that the period extends from the startTime forward into the future.

high: Option<String>

Internal use. Delivers highest price value in total interval. Used for chart scaling. A string constructed as ‘highestPricepriceFactor/totalVolumevolumeFactor/minutesFromStartTime’.

low: Option<String>

Internal use. Delivers lowest price value in total interval. Used for chart scaling. A string constructed as ‘lowestPricepriceFactor/totalVolumevolumeFactor/minutesFromStartTime’.

md_availability: Option<String>

A three-character string reflecting the nature of available data. R = Realtime, D = Delayed, Z = Frozen, Y = Frozen Delayed, N = Not Subscribed. P = Snapshot, p = Consolidated. B = Top of book.

message_version: Option<i32>

Internal use. Reflects the version of the response schema used.

mkt_data_delay: Option<i32>

Number of milliseconds taken to satisfy this historical data request.

negative_capable: Option<bool>

Indicates whether instrument is capable of negative pricing.

outside_rth: Option<bool>

Indicates whether data from outside regular trading hours is included in the response.

points: Option<i32>

Count of the number of bars returned in the data array.

price_display_rule: Option<i32>

Internal use. Governs application of pricing display rule.

price_display_value: Option<String>

Internal use. Governs rendering of displayed pricing.

price_factor: Option<i32>

Internal use. Used to scale Client Portal chart Y-axis.

server_id: Option<String>

Internal use. Identifier of the request.

start_time: Option<String>

UTC date and time of the start (chronologically earlier) of the complete period in format YYYYMMDD-hh:mm:ss.

symbol: Option<String>

Symbol of the request instrument.

text: Option<String>

Description or company name of the instrument.

time_period: Option<String>

The client-specified period value.

trading_day_duration: Option<i32>

Length of instrument’s trading day in seconds.

travel_time: Option<i32>

Internal time in flight to serve the request.

volume_factor: Option<i32>

Internal use. Used to scale volume histograms.