pub struct IserverScannerParamsFilterList {
pub code: Option<String>,
pub combo_values: Option<Vec<IserverScannerParamsFilterListComboValue>>,
pub display_name: Option<String>,
pub group: Option<String>,
pub type: Option<String>,
}Fields
code: Option<String>Value used for the market scanner request.
combo_values: Option<Vec<IserverScannerParamsFilterListComboValue>>combo values when type equals to combo
display_name: Option<String>Returns the human-readable identifier for the filter.
group: Option<String>Returns the group of filters the request is affiliated with.
type: Option<String>Returns the type of value to be used in the request. This can indicate a range based value, or if it should be a single value.