pub struct IserverScannerRunResponseContract {
pub available_chart_periods: Option<String>,
pub column_name: Option<String>,
pub company_name: Option<String>,
pub con_id: Option<i32>,
pub conidex: Option<String>,
pub contract_description_1: Option<String>,
pub listing_exchange: Option<String>,
pub sec_type: Option<String>,
pub server_id: Option<String>,
pub symbol: Option<String>,
}Fields
available_chart_periods: Option<String>Internal Use Only
column_name: Option<String>Always returned for the first contract.
company_name: Option<String>Returns the company long name.
con_id: Option<i32>Returns the contract ID of the contract.
conidex: Option<String>Returns the contract ID of the contract.
contract_description_1: Option<String>For derivatives like Futures, the local symbol of the contract will be returned.
listing_exchange: Option<String>Returns the primary listing exchange of the contract.
sec_type: Option<String>Returns the security type of the contract.
server_id: Option<String>Contract’s index in relation to the market scanner type’s sorting priority.
symbol: Option<String>Returns the contract’s ticker symbol.