pub struct LiveSessionToken200Response {
pub diffie_hellman_challenge: Option<String>,
pub live_session_token_expiration: Option<i32>,
pub live_session_token_signature: Option<String>,
}Fields
diffie_hellman_challenge: Option<String>Diffie-Hellman challenge value used to compute live session token locally by client.
live_session_token_expiration: Option<i32>Unix timestamp in milliseconds of time of live session token computation by IB. Live session tokens are valid for 24 hours from this time.
live_session_token_signature: Option<String>Signature value used to validate successful client-side computation of live session token.