pub struct ModelPositionResponse {
pub cash: Option<Vec<ModelPositionResponseCash>>,
pub mismatched: Option<bool>,
pub model: Option<String>,
pub nlv: Option<f64>,
pub position_list: Option<Vec<ModelPositionResponsePositionList>>,
pub position_ts: Option<i64>,
pub req_id: Option<i32>,
pub stk_only: Option<bool>,
pub subscription_status: Option<i32>,
pub total_dlv: Option<f64>,
pub total_mv: Option<f64>,
}Fields
cash: Option<Vec<ModelPositionResponseCash>>An object representing each currency held in the model.
mismatched: Option<bool>Notes if the Actual allocation has become misalligned with the Target.
model: Option<String>Name of the model.
nlv: Option<f64>Market value of the model.
position_list: Option<Vec<ModelPositionResponsePositionList>>List of object containing each equity in the model.
position_ts: Option<i64>Epoch timestamp when the position was retrieved.
req_id: Option<i32>Request identifier to uniquely track a request.
stk_only: Option<bool>Describes if the model contains only stocks.
subscription_status: Option<i32>Describes if the model is in polling mode.
total_dlv: Option<f64>Diplayed total liquidation value of the model.
total_mv: Option<f64>Market value of the entire position.