pub struct ModelPositionResponseCash {
pub actual: Option<f64>,
pub ccy: Option<String>,
pub exchange_rate: Option<f64>,
pub instrument_imbalance: Option<f64>,
pub mv: Option<f64>,
pub target: Option<f64>,
}Fields
actual: Option<f64>Actual percent of the model held in the postion.
ccy: Option<String>Currency symbol.
exchange_rate: Option<f64>Exchange rate of the account base currency to the model base currency.
instrument_imbalance: Option<f64>Describes the percentage of imbalance of the actual allocation from the model.
mv: Option<f64>Market value of the position.
target: Option<f64>Target percentage of the model to hold in the position.