pub struct ModelPositionResponsePositionList {Show 14 fields
pub actual: Option<f64>,
pub actual_range_max: Option<f64>,
pub actual_range_min: Option<f64>,
pub ccy: Option<String>,
pub conid: Option<f64>,
pub dlv: Option<f64>,
pub exchange_rate: Option<f64>,
pub flags: Option<i32>,
pub instrument: Option<String>,
pub instrument_imbalance: Option<f64>,
pub mismatch_type: Option<f64>,
pub mv: Option<f64>,
pub position: Option<f64>,
pub target: Option<f64>,
}Fields
actual: Option<f64>Actual percent of the model held in the postion.
actual_range_max: Option<f64>Maximum accepted tolerance above the target.
actual_range_min: Option<f64>Minimum accepted tolerance below the target.
ccy: Option<String>Currency symbol.
conid: Option<f64>Contract identifier for the instrument.
dlv: Option<f64>Displayed liquidation value.
exchange_rate: Option<f64>Used internally for client portal. Should be ignored.
flags: Option<i32>Used internally for client portal. Should be ignored.
instrument: Option<String>Symbol of the position.
instrument_imbalance: Option<f64>Describes the percentage of imbalance of the actual allocation from the model.
mismatch_type: Option<f64>Used internally for client portal. Should be ignored.
mv: Option<f64>Market Value.
position: Option<f64>The total size of the position held in the model.
target: Option<f64>The desired allocation percentage of the position in the model.