pub struct ModelSummaryResponse {
pub bootstrapped: Option<bool>,
pub custom_index: Option<bool>,
pub desc: Option<String>,
pub is_static: Option<bool>,
pub mismatch: Option<bool>,
pub model: Option<String>,
pub nlv: Option<f64>,
pub num_accounts: Option<i32>,
pub req_id: Option<i32>,
pub subscription_status: Option<i32>,
}Fields
bootstrapped: Option<bool>Used internally for client portal designation. Should be ignored.
custom_index: Option<bool>Used internally for client portal. Should be ignored.
desc: Option<String>Personal description of model to read in IBKR GUI elements.
is_static: Option<bool>Determine if investing and rebalancing should be handled statically or dynamically. * true - Static models will always use the original targets. * false - Dynamic models will adjust allocation in response to market movements.
mismatch: Option<bool>Notes if the Actual allocation has become misalligned with the Target.
model: Option<String>Name of the model.
nlv: Option<f64>Net Liquidation of the model.
num_accounts: Option<i32>Lists the number of accounts held within the model.
req_id: Option<i32>Request identifier to uniquely track a request.
- Example:
Some(540_609i32)
subscription_status: Option<i32>Describes if the model is in polling mode.