pub struct NotificationRequestBody {
pub order_id: Option<i32>,
pub req_id: Option<String>,
pub text: Option<String>,
}Fields
order_id: Option<i32>IB-assigned order identifier obtained from the ntf websocket message that delivered the server prompt.
- Example:
Some(987_654_321i32)
req_id: Option<String>IB-assigned request identifier obtained from the ntf websocket message that delivered the server prompt.
- Example:
Some("12345".to_string())
text: Option<String>The selected value from the “options” array delivered in the server prompt ntf websocket message.
- Example:
Some("Yes".to_string())