pub struct NotificationsNotification {
pub d: Option<String>,
pub fc: Option<String>,
pub ht: Option<i32>,
pub id: Option<String>,
pub md: Option<String>,
pub ms: Option<String>,
pub r: Option<String>,
}Fields
d: Option<String>Notification date as an epoch string.
fc: Option<String>FYI code, we can use it to find whether the disclaimer is accepted or not in settings
ht: Option<i32>HT
- Example:
Some(0i32)
id: Option<String>Unique way to reference the notification.
md: Option<String>Content of notification.
ms: Option<String>Title of notification.
r: Option<String>Return if the notification was read or not. Value Format: 0: Disabled; 1: Enabled.