pub struct OrderCancelSuccess {
pub account: Option<String>,
pub conid: Option<String>,
pub msg: Option<String>,
pub order_id: Option<String>,
}Expand description
Acknowledges IB’s acceptance of the request to cancel the order. Does not report whether the cancellation can or will ultimately be enacted.
Fields
account: Option<String>IB account to which the order was originally set to clear.
conid: Option<String>IB contract ID of the order ticket’s instrument.
msg: Option<String>Indicates success with value ‘Request was submitted’
order_id: Option<String>IB order ID of the order ticket requested for cancellation.