pub struct OrderPreview {
pub amount: Option<OrderPreviewAmount>,
pub equity: Option<OrderPreviewEquity>,
pub error: Option<String>,
pub initial: Option<OrderPreviewInitial>,
pub maintenance: Option<OrderPreviewMaintenance>,
pub position: Option<OrderPreviewPosition>,
pub warn: Option<String>,
}Expand description
Projected costs and changes to margin and equity values in the account, if the order ticket were executed in full.
Fields
amount: Option<OrderPreviewAmount>Describes the projected costs associated with the order ticket.
equity: Option<OrderPreviewEquity>Describes the projected change to the account’s equity.
error: Option<String>Human-readable text of an error message, if applicable. Otherwise null.
initial: Option<OrderPreviewInitial>Describes the projected change to initial margin.
maintenance: Option<OrderPreviewMaintenance>Describes the projected change to maintenance margin.
position: Option<OrderPreviewPosition>Describes the projected change to the account’s position in the instrument.
warn: Option<String>Human-readable text of warning message, if applicable. Otherwise null.