pub struct OrderPreviewAmount {
pub amount: Option<String>,
pub commission: Option<String>,
pub total: Option<String>,
}Expand description
Describes the projected costs associated with the order ticket.
Fields
amount: Option<String>Projected cost of the order, current reference price times total quantity.
commission: Option<String>Projected commissions and fees associated with the order.
total: Option<String>Sum of projected cost and commission values for the order.