pub struct OrderReplyMessageOrderReplyMessage {
pub id: Option<String>,
pub is_suppressed: Option<bool>,
pub message: Option<Vec<String>>,
pub message_ids: Option<Vec<String>>,
}Expand description
An object containing order reply messages emitted against a single order ticket.
Fields
id: Option<String>The replyId UUID of the order ticket’s emitted order reply messages, used to confirm them and proceed. Use the POST /iserver/reply/{replyId} endpoint to confirm an order reply message.
is_suppressed: Option<bool>Internal use. Always delivers value ‘false’.
message: Option<Vec<String>>An array containing the human-readable text of all order reply messages emitted for the order ticket.
message_ids: Option<Vec<String>>An array containing identifiers that categorize the types of order reply messages that have been emitted. Elements of this array are ordered so that indicies match the corresponding human-readable text strings in the ‘message’ array. A messageId can typically be passed in the POST /iserver/questions/suppress endpoint to auto-accept a given warning message.