pub struct PerformanceResponseNav {
pub data: Option<Vec<PerformanceResponseNavDatum>>,
pub dates: Option<Vec<Value>>,
pub freq: Option<String>,
}Expand description
Net asset value data for the account or consolidated accounts. NAV data is not applicable to benchmarks.
Fields
data: Option<Vec<PerformanceResponseNavDatum>>Contains the affiliated ‘nav’ data.
dates: Option<Vec<Value>>Returns the array of dates formatted as strings corresponding to your frequency, the length should be same as the length of returns inside data.
freq: Option<String>Displays the values corresponding to a given frequency.