Portfolio2PositionsPortfolio2position

Struct Portfolio2PositionsPortfolio2position 

pub struct Portfolio2PositionsPortfolio2position {
Show 17 fields pub asset_class: Option<String>, pub avg_cost: Option<Value>, pub avg_price: Option<f64>, pub conid: Option<i32>, pub currency: Option<String>, pub description: Option<String>, pub group: Option<String>, pub is_last_to_loq: Option<bool>, pub market_price: Option<f64>, pub market_value: Option<f64>, pub model: Option<String>, pub position: Option<f64>, pub realized_pnl: Option<f64>, pub sec_type: Option<String>, pub sector: Option<String>, pub timestamp: Option<i32>, pub unrealized_pnl: Option<f64>,
}

Fields

asset_class: Option<String>

Asset class of the requested instrument.

avg_cost: Option<Value>

The account’s average cost for its position.

avg_price: Option<f64>

The account’s average price for its position.

conid: Option<i32>

IB contract ID for the instrument.

currency: Option<String>

Currency in which the instrument trades.

description: Option<String>

Contract’s local symbol

group: Option<String>

Industry sub-categorization of the instrument.

is_last_to_loq: Option<bool>market_price: Option<f64>

Current market price of the instrument, in the instrument’s currency.

market_value: Option<f64>

Current market value of the account’s position in the instrument, in the instrument’s currency.

model: Option<String>

Name of the model portfolio in which the account is invested that contributes this position.

position: Option<f64>

Size of position in units of instrument.

realized_pnl: Option<f64>

Realized PnL for the instrument in the instrument’s currency.

sec_type: Option<String>

The security type of the instrument.

sector: Option<String>

Industry sector categorization of the instrument.

timestamp: Option<i32>

Time taken to retrieve position data in milliseconds.

unrealized_pnl: Option<f64>

Unrealized PnL for the instrument in the account.