pub struct PortfolioAllocationsAssetClass {
pub long: Option<HashMap<String, f64>>,
pub short: Option<HashMap<String, f64>>,
}Expand description
Object containing values of positions sorted by long/short and asset class.
Fields
long: Option<HashMap<String, f64>>Object containing value of long positions in the account aggregated by asset class.
short: Option<HashMap<String, f64>>Object containing value of short positions in the account aggregated by asset class.