pub struct PortfolioAllocationsGroup {
pub long: Option<HashMap<String, f64>>,
pub short: Option<HashMap<String, f64>>,
}Expand description
Object containing values of positions sorted by long/short and Sector Group.
Fields
long: Option<HashMap<String, f64>>Object containing value of long positions in the account aggregated by Sector Group.
short: Option<HashMap<String, f64>>Object containing value of short positions in the account aggregated by Sector Group.