pub struct PortfolioSummaryValue {
pub amount: Option<f64>,
pub currency: Option<f64>,
pub is_null: Option<bool>,
pub severity: Option<i32>,
pub timestamp: Option<i32>,
pub value: Option<String>,
}Fields
amount: Option<f64>Numerical data for the associated key.
currency: Option<f64>The currency in which the value of the ‘amount’ field is denominated.
is_null: Option<bool>Indicates whether the associated key’s value does not exist, as opposed to a value of zero.
severity: Option<i32>severity
timestamp: Option<i32>Unix epoch timestamp of returned data in milliseconds.
value: Option<String>String and boolean (non-numerical) data for the associated key.