pub struct PostGwApiV1AccountsDocumentsRequest {
pub body: AccountRequestBody,
}Expand description
Provides mechanism to submit Agreements and Disclosures to IBKR once a day instead of with each application. We store these documents on the servers and will use them for new application requests submitted that day.
- Documents will need to be submitted once a day (before the Applications are submitted). PDFs will be displayed and submitted as is- no changes/edits will be made to the actual PDF files.
- This end-point will not process any Tax Form Documents. Tax Form document should be submitted with every application
- If submitted in the morning, you only need to include the Tax Form attachment for each applicant. Otherwise, you will need to include PDFs with each application (Create Account).
Scope:
accounts.writeSecurity Policy:
Signed JWT
Fields
body: AccountRequestBodyImplementations
Sourceimpl PostGwApiV1AccountsDocumentsRequest
impl PostGwApiV1AccountsDocumentsRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<PostGwApiV1AccountsResponse>
pub async fn parse_response( req: Response, ) -> Result<PostGwApiV1AccountsResponse>
Parse the HTTP response into the response enum.