pub struct PreviewMarginImpactRequest {
pub path: PreviewMarginImpactRequestPath,
pub body: OrdersSubmissionRequest,
}Expand description
Preview the projected effects of an order ticket or bracket of orders, including cost and changes to margin and account equity.
Fields
path: PreviewMarginImpactRequestPathbody: OrdersSubmissionRequestImplementations
Sourceimpl PreviewMarginImpactRequest
impl PreviewMarginImpactRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<PreviewMarginImpactResponse>
pub async fn parse_response( req: Response, ) -> Result<PreviewMarginImpactResponse>
Parse the HTTP response into the response enum.