pub struct RuleRequestBody {
pub conid: i32,
pub is_buy: Option<bool>,
pub modify_order: Option<bool>,
pub order_id: Option<i32>,
}Fields
conid: i32Contract identifier for the interested contract.
is_buy: Option<bool>Side of the market rules apply too. Set to true for Buy Orders, set to false for Sell orders.
modify_order: Option<bool>Used to find trading rules related to an existing order.
order_id: Option<i32>Specify the order identifier used for tracking a given order.