pub struct SaveRequestBody {
pub cash_targets: Vec<SaveRequestBodyCashTarget>,
pub desc: String,
pub is_static: bool,
pub model: String,
pub position_targets: Vec<SaveRequestBodyPositionTarget>,
pub req_id: i32,
}Fields
cash_targets: Vec<SaveRequestBodyCashTarget>Array target cash objects
desc: StringPersonal description of model to read in IBKR GUI elements.
is_static: boolDetermine if investing and rebalancing should be handled statically or dynamically.
true- Static models will always use the original targets.false- Dynamic models will adjust allocation in response to market movements.
model: StringName of your model.
- Example:
"Sample-Model".to_string()
position_targets: Vec<SaveRequestBodyPositionTarget>List containing all contracts to hold in the model.
req_id: i32Request identifier to uniquely track a request.
- Example:
540_607i32