pub struct SaveRequestBodyPositionTarget {
pub conid: Option<i32>,
pub target: Option<f64>,
}Fields
conid: Option<i32>Contract identifier, conid, to designate which security to hold.
- Example:
Some(265_598i32)
target: Option<f64>Percentage of model to distribute to the given currency.
- Example:
Some(0.0)