pub struct ScheduleResponseSchedules {
pub date: Option<ScheduleResponseSchedulesDate>,
}Expand description
Returns a series of date objects of the given contract.
Fields
date: Option<ScheduleResponseSchedulesDate>object containing the of hours objects detailing extended and liquid trading.