pub struct SearchRequestBody {
pub fund: Option<bool>,
pub fund_family_conid_ex: Option<String>,
pub more: Option<bool>,
pub name: Option<bool>,
pub pattern: Option<bool>,
pub referrer: Option<String>,
pub sec_type: Option<GetContractSymbolsRequestQuerySecType>,
pub symbol: String,
}Fields
fund: Option<bool>fund search
fund_family_conid_ex: Option<String>more: Option<bool>name: Option<bool>Denotes if the symbol value is the ticker symbol or part of the company’s name.
pattern: Option<bool>pattern search
referrer: Option<String>sec_type: Option<GetContractSymbolsRequestQuerySecType>Available underlying security types:
STK- Represents an underlying as a Stock security type.IND- Represents an underlying as an Index security type.BOND- Represents an underlying as a Bond security type.
symbol: StringThe ticker symbol, bond issuer type, or company name of the equity you are looking to trade.
- Example:
"AAPL".to_string()