pub struct SecDefInfoResponse {
pub company_name: Option<String>,
pub conid: Option<i32>,
pub currency: Option<String>,
pub exchange: Option<String>,
pub listing_exchange: Option<String>,
pub maturity_date: Option<String>,
pub price_rendering: Option<String>,
pub right: Option<IndividualPositionPutOrCall>,
pub sec_type: Option<String>,
pub strike: Option<f64>,
pub ticker: Option<String>,
pub valid_exchanges: Option<String>,
}Fields
company_name: Option<String>Name of the company for the given contract.
conid: Option<i32>Contract Identifier of the given contract.
currency: Option<String>Traded currency allowed for the given contract.
exchange: Option<String>Exchange requesting data for.
listing_exchange: Option<String>Primary listing exchange for the given contract.
maturity_date: Option<String>Date of expiration for the given contract.
price_rendering: Option<String>right: Option<IndividualPositionPutOrCall>Set the right for the given contract. * C - for Call options. * P - for Put options.
sec_type: Option<String>Security type for the given contract.
strike: Option<f64>Returns the given strike value for the given contract.
ticker: Option<String>Ticker symbol for the given contract
valid_exchanges: Option<String>Series of all valid exchanges the contract can be traded on in a single comma-separated string.