pub struct SingleHistoricalBarLast {
pub c: Option<f64>,
pub h: Option<f64>,
pub l: Option<f64>,
pub o: Option<f64>,
pub t: Option<i32>,
pub v: Option<f64>,
}Expand description
Object containing Last or Trades data for a single OHLC bar.
Fields
c: Option<f64>Closing value of the bar. Indicates the final traded price of the bar.
h: Option<f64>High value of the bar. Indicates the highest traded price of the bar.
l: Option<f64>Low value of the bar. Indicates the lowest traded price of the bar.
o: Option<f64>Opening value of the bar. Indicates first traded price of the bar.
t: Option<i32>Unix timestamp of the start (chronologically earlier) of the bar.
v: Option<f64>Volume value of the bar, returned only for “Last” barType.