pub struct SingleHistoricalBarMidpoint {
pub c: Option<f64>,
pub h: Option<f64>,
pub l: Option<f64>,
pub o: Option<f64>,
pub t: Option<i32>,
pub v: Option<f64>,
}Expand description
Object containing Midpoint data for a single OHLC bar.
Fields
c: Option<f64>Closing value of the bar. Indicates the last midpoint price traded price during the bar.
h: Option<f64>High value of the bar. Indicates the highest midpoint price traded price during the bar.
l: Option<f64>Low value of the bar. Indicates the lowest midpoint price traded price during the bar.
o: Option<f64>Opening value of the bar. Indicates the starting midpoint price traded price during the bar.
t: Option<i32>Unix timestamp of the start (chronologically earlier) of the bar.
v: Option<f64>Volume value of the bar. Always returns 0.