SingleOrderSubmissionRequest

Struct SingleOrderSubmissionRequest 

pub struct SingleOrderSubmissionRequest {
Show 29 fields pub acct_id: Option<String>, pub all_or_none: Option<bool>, pub aux_price: Option<f64>, pub c_oid: Option<String>, pub cash_qty: Option<f64>, pub conid: i32, pub conidex: Option<String>, pub ext_operator: Option<String>, pub is_ccy_conv: Option<bool>, pub is_single_group: Option<bool>, pub json_payload: Option<SingleOrderSubmissionRequestJsonPayload>, pub listing_exchange: Option<String>, pub manual_indicator: Option<bool>, pub order_type: String, pub outside_rth: Option<bool>, pub parent_id: Option<String>, pub price: Option<f64>, pub quantity: f64, pub referrer: Option<String>, pub sec_type: Option<String>, pub side: Side, pub strategy: Option<String>, pub strategy_parameters: Option<SingleOrderSubmissionRequestStrategyParameters>, pub tax_optimizer_id: Option<String>, pub ticker: Option<String>, pub tif: OrderStatusTif, pub trailing_amt: Option<f64>, pub trailing_type: Option<SingleOrderSubmissionRequestTrailingType>, pub use_adaptive: Option<bool>,
}
A single order ticket.

Fields

acct_id: Option<String>

Receiving account of the order ticket.

all_or_none: Option<bool>

Instructs IB to execute the order entirely or not execute at all.

aux_price: Option<f64>

Additional price value used in certain order types, such as stop orders.

c_oid: Option<String>

Client-configurable order identifier.

cash_qty: Option<f64>

Quantity of currency used with cash quantity orders.

conid: i32

IB contract ID of the instrument.

conidex: Option<String>

Contract ID and routing destination together in format 123456@EXCHANGE.

ext_operator: Option<String>

ExtOperator is used to identify external operator

is_ccy_conv: Option<bool>

Indicates that a forex order is for currency conversion and should not entail a virtual forex position in the account, where applicable.

is_single_group: Option<bool>

Indicates that all orders in the containing array are to be treated as an OCA group.

json_payload: Option<SingleOrderSubmissionRequestJsonPayload>listing_exchange: Option<String>

The listing exchange of the instrument.

manual_indicator: Option<bool>

For all orders for US Futures products, clients must submit this flag to indicate whether the order was originated manually (by a natural person) or automatically (by an automated trading system transmitting orders without human intervention). Submit a True value to indicate a manually originated order, and submit a False value to indicate an automated order. Orders for USFUT products that do not include this field will be rejected.

order_type: String

IB order type identifier.

outside_rth: Option<bool>

Instructs IB to permit the order to execute outside of regular trading hours.

parent_id: Option<String>

If the order ticket is a child order in a bracket, the parentId field must be set equal to the cOID provided for the parent order.

price: Option<f64>

Price of the order ticket, where applicable.

quantity: f64

Quantity of the order ticket in units of the instrument.

referrer: Option<String>

IB internal identifier for order entry UI element.

sec_type: Option<String>

IB asset class identifier.

side: Side

Side of the order ticket.

strategy: Option<String>

The name of an execution algorithm.

strategy_parameters: Option<SingleOrderSubmissionRequestStrategyParameters>

Parameters governing the selected algorithm, if applicable.

tax_optimizer_id: Option<String>

Identifies set of tax lots selected, for gains and losses management.

ticker: Option<String>

Ticker symbol of the instrument.

tif: OrderStatusTif

Time in force of the order ticket.

trailing_amt: Option<f64>

Offset used with Trailing orders.

trailing_type: Option<SingleOrderSubmissionRequestTrailingType>

Specifies the type of trailing used with a Trailing order.

use_adaptive: Option<bool>

Instructs IB to apply the Price Management Algo.