pub struct SingleOrderSubmissionRequestJsonPayloadAllocationProfile {
pub alloc_type: Option<SingleOrderSubmissionRequestJsonPayloadAllocationProfileAllocType>,
pub allocations: Option<Vec<SingleOrderSubmissionRequestJsonPayloadAllocationProfileAllocation>>,
}Expand description
The assigned contents for how the order should be allocated amongst subaccount(s).
Fields
alloc_type: Option<SingleOrderSubmissionRequestJsonPayloadAllocationProfileAllocType>The allocation type to define how shares should be distributed. A warning message to be pre-approved.
SHARE- Designate the allocation amounts as a quantity of shares.CASH- Designate the allocation amounts as a quantity of a cash quantity to allocate.
allocations: Option<Vec<SingleOrderSubmissionRequestJsonPayloadAllocationProfileAllocation>>List of accounts to allocate a trade and the affiliated quantity.