pub struct SsoValidateResponse {Show 17 fields
pub auth_time: Option<i32>,
pub credential: Option<String>,
pub expires: Option<i32>,
pub ip: Option<String>,
pub is_free_trial: Option<bool>,
pub is_master: Option<bool>,
pub landing_app: Option<String>,
pub paper_user_name: Option<String>,
pub qualified_for_mobile_auth: Option<bool>,
pub result: Option<bool>,
pub sf_enabled: Option<bool>,
pub user_id: Option<i32>,
pub user_name: Option<String>,
pub features: Option<SsoValidateResponseFeatures>,
pub last_accessed: Option<i32>,
pub login_type: Option<i32>,
pub region: Option<String>,
}Fields
auth_time: Option<i32>Returns the time of authentication in epoch time.
credential: Option<String>Returns the underlying username of the account.
expires: Option<i32>Returns the time until SSO session expiration in milliseconds.
ip: Option<String>Internal use only. Does not reflect the IP address of the user.
is_free_trial: Option<bool>Returns if the account is a trial account or a funded account.
is_master: Option<bool>Returns whether the account is a master account (true) or subaccount (false).
landing_app: Option<String>Used for Client Portal (Internal use only)
paper_user_name: Option<String>Returns the paper username for the account.
qualified_for_mobile_auth: Option<bool>Returns if the customer requires two factor authentication.
result: Option<bool>Confirms if validation was successful. True if session was validated; false if not.
sf_enabled: Option<bool>(Internal use only)
user_id: Option<i32>Internal user identifier.
user_name: Option<String>current username logged in for the session.
features: Option<SsoValidateResponseFeatures>Returns supported features such as bonds and option trading.
last_accessed: Option<i32>Returns the last time the user was accessed in epoch time.
login_type: Option<i32>Returns the login type. 1 for Live, 2 for Paper
region: Option<String>Returns the region connected to internally.