pub struct SsoValidateResponseFeatures {
pub bond: Option<bool>,
pub calendar: Option<bool>,
pub envs: Option<String>,
pub new_mf: Option<bool>,
pub option_chains: Option<bool>,
pub realtime: Option<bool>,
pub wlms: Option<bool>,
}Expand description
Returns supported features such as bonds and option trading.
Fields
bond: Option<bool>Returns if bonds can be traded.
calendar: Option<bool>Returns if trading calendars are enabled
envs: Option<String>Returns the connecting environment to distinguish production or paper.
new_mf: Option<bool>Internal Use Only
option_chains: Option<bool>Returns if option chains can be retrieved in the account.
realtime: Option<bool>Returns if realtime market data is available
wlms: Option<bool>Internal Use Only