pub struct StmtRequest {
pub account_id: String,
pub account_ids: Option<Vec<String>>,
pub crypto_consol_if_available: Option<bool>,
pub end_date: String,
pub gzip: Option<bool>,
pub language: Option<String>,
pub mime_type: Option<String>,
pub multi_account_format: Option<String>,
pub start_date: String,
}Fields
account_id: Stringaccount id
account_ids: Option<Vec<String>>array of account id’s
- Example:
Some(vec!["U123", "U456"].to_string())
crypto_consol_if_available: Option<bool>crypto consolidate flag, If request contains any accounts with crypto segment, will turn request into Crypto Consolidated
end_date: Stringto date
gzip: Option<bool>to gzip the whole response pass true
language: Option<String>two character ISO language code
- Example:
Some("en, fr defaults to en (english)".to_string())
mime_type: Option<String>output format
- Example:
Some("application/pdf, text/html, or text/csv".to_string())
multi_account_format: Option<String>possible values are consolidate, concatenate, or customConsolidate
start_date: Stringfrom date