pub struct Strike200Response {
pub call: Option<Vec<f64>>,
pub put: Option<Vec<f64>>,
}Fields
call: Option<Vec<f64>>Array containing a series of comma separated values representing potential call strikes for the instrument.
put: Option<Vec<f64>>Array containing a series of comma separated values representing potential put strikes for the instrument.