pub struct SubAccountsAccountDatum {
pub key: Option<SubAccountsAccountDatumKey>,
pub value: Option<String>,
}Fields
key: Option<SubAccountsAccountDatumKey>Defines the value of the object
AvailableEquity- Indicates the value relates to the Available Equity held within the accountNetLiquidation- Indicates the value relates to the Net Liquidation held within the account
value: Option<String>Contains the price value affiliated with the key.