pub struct SummaryOfAccountBalancesResponseTotal {
pub mtd_interest: Option<String>,
pub nt_lqdtn_uncrtnty: Option<String>,
pub pndng_dbt_crd_chrgs: Option<String>,
pub prvs_dy_eqty_wth_ln_vl: Option<String>,
pub cash: Option<String>,
pub equity_with_loan: Option<String>,
pub net_liquidation: Option<String>,
pub sec_gross_pos_val: Option<String>,
}Expand description
Contains total balance details for the account.
Fields
mtd_interest: Option<String>Total Month-to-date interest.
nt_lqdtn_uncrtnty: Option<String>Displays the uncertainty of the Net Liquidating Value associated with after-hours price changes.
pndng_dbt_crd_chrgs: Option<String>Any pending charges for the IBKR debit account.
prvs_dy_eqty_wth_ln_vl: Option<String>The accounts equity balance including loan value.
cash: Option<String>Total cash balance in the account
equity_with_loan: Option<String>Cash AccountsSettled cashMargin AccountsTotal cash value + stock value + bond value + fund value + European & Asian options value.
net_liquidation: Option<String>The basis for determining the price of the assets in your account.
sec_gross_pos_val: Option<String>Equals the sum of the absolute value of all positions except cash, index futures and US treasuries.