TradesResponseTradesResponse

Struct TradesResponseTradesResponse 

pub struct TradesResponseTradesResponse {
Show 28 fields pub account: Option<String>, pub account_code: Option<String>, pub account_allocation_name: Option<String>, pub clearing_id: Option<String>, pub clearing_name: Option<String>, pub commission: Option<String>, pub company_name: Option<String>, pub conid: Option<String>, pub conid_ex: Option<String>, pub contract_description_1: Option<String>, pub exchange: Option<String>, pub execution_id: Option<String>, pub is_event_trading: Option<AlertActivationRequestAlertActive>, pub liquidation_trade: Option<AlertActivationRequestAlertActive>, pub listing_exchange: Option<String>, pub net_amount: Option<f64>, pub order_description: Option<String>, pub order_id: Option<f64>, pub order_ref: Option<String>, pub price: Option<String>, pub sec_type: Option<OrderStatusSecType>, pub side: Option<TradesResponseTradesResponseSide>, pub size: Option<f64>, pub submitter: Option<String>, pub supports_tax_opt: Option<AlertActivationRequestAlertActive>, pub symbol: Option<String>, pub trade_time: Option<String>, pub trade_time_r: Option<i64>,
}
Object containing details of a single execution.

Fields

account: Option<String>

The IB account ID of the account that received the execution.

account_code: Option<String>

The IB account ID of the account that received the execution.

account_allocation_name: Option<String>

The IB account ID of the account that received the execution.

clearing_id: Option<String>

Identifier of the firm clearing the trade. Value is “IB” if account is cleared by Interactive Brokers.

clearing_name: Option<String>

Name of the firm clearing the trade. Value is “IB” if account is cleared by Interactive Brokers.

commission: Option<String>

Commissions incurred by the execution. May also include

company_name: Option<String>

Name of business associated with instrument, or otherwise description of instrument.

conid: Option<String>

Contract ID of the order’s instrument.

conid_ex: Option<String>

Contract ID and routing destination in format 123456@EXCHANGE.

contract_description_1: Option<String>

Human-readable description of the order’s instrument.

exchange: Option<String>

The exchange or other venue on which the execution occurred.

execution_id: Option<String>

IB-assigned execution identifier.

is_event_trading: Option<AlertActivationRequestAlertActive>

Indicates whether the order ticket is an Event Trading order.

liquidation_trade: Option<AlertActivationRequestAlertActive>

Indicates whether the trade is the result of a liquidiation by IB.

listing_exchange: Option<String>

The primary exchange on which the instrument is listed.

net_amount: Option<f64>

net_amount

order_description: Option<String>

Human-readable description of the outcome of the execution.

order_id: Option<f64>

Order ID

order_ref: Option<String>

The client-provided customer order identifier. Specified via cOID during order submission in the Web API.

price: Option<String>

The price at which the execution occurred.

sec_type: Option<OrderStatusSecType>

IB asset class identifier.

side: Option<TradesResponseTradesResponseSide>

Side of the execution.

size: Option<f64>

The size of the execution in units of the instrument.

submitter: Option<String>

The IB username that originated the order ticket against which the execution occurred.

supports_tax_opt: Option<AlertActivationRequestAlertActive>

Indicates whether the order is supported by IB’s Tax Optimization tool.

symbol: Option<String>

Symbol of the instrument involved in the execution.

trade_time: Option<String>

UTC date and time of the execution in format YYYYMMDD-hh:mm:ss.

trade_time_r: Option<i64>

Unix timestamp of the execution time in milliseconds.