pub struct TradingScheduleTradingSchedule {
pub description: Option<String>,
pub exchange: Option<String>,
pub id: Option<String>,
pub schedules: Option<Vec<TradingScheduleTradingScheduleSchedule>>,
pub timezone: Option<String>,
pub trade_venue_id: Option<String>,
}Fields
description: Option<String>exchange description
exchange: Option<String>short exchange name
id: Option<String>Exchange parameter id
schedules: Option<Vec<TradingScheduleTradingScheduleSchedule>>Always contains at least one ‘tradingTime’ and zero or more ‘sessionTime’ tags
timezone: Option<String>References the time zone corresponding to the listed dates and times.
trade_venue_id: Option<String>Reference on a trade venue of given exchange parameter