pub struct TransactionsResponse {
pub currency: Option<String>,
pub from: Option<i32>,
pub id: Option<String>,
pub includes_real_time: Option<bool>,
pub nd: Option<i32>,
pub rc: Option<i32>,
pub rpnl: Option<TransactionsResponseRpnl>,
pub to: Option<i32>,
pub transactions: Option<Vec<TransactionsResponseTransaction>>,
}Fields
currency: Option<String>Returns the currency the account is traded in.
from: Option<i32>Returns the epoch time for the start of requests.
id: Option<String>Returns the request identifier, getTransactions.
includes_real_time: Option<bool>Returns if the trades are up to date or not.
nd: Option<i32>Client portal use only
rc: Option<i32>Client portal use only
rpnl: Option<TransactionsResponseRpnl>Returns the object containing the realized pnl for the contract on the date.
to: Option<i32>Returns the epoch time for the end of requests.
transactions: Option<Vec<TransactionsResponseTransaction>>Lists all supported transaction values.