pub struct TransactionsResponseRpnl {
pub amt: Option<String>,
pub data: Option<Vec<Value>>,
pub items: Option<TransactionsResponseRpnlItems>,
}Expand description
Returns the object containing the realized pnl for the contract on the date.
Fields
amt: Option<String>Provides the total amount gained or lost from all days returned
data: Option<Vec<Value>>Returns an array of realized pnl objects.
items: Option<TransactionsResponseRpnlItems>Trait Implementations
Sourceimpl Clone for TransactionsResponseRpnl
impl Clone for TransactionsResponseRpnl
Sourcefn clone(&self) -> TransactionsResponseRpnl
fn clone(&self) -> TransactionsResponseRpnl
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionsResponseRpnl
impl Debug for TransactionsResponseRpnl
Sourceimpl Default for TransactionsResponseRpnl
impl Default for TransactionsResponseRpnl
Sourceimpl<'de> Deserialize<'de> for TransactionsResponseRpnl
impl<'de> Deserialize<'de> for TransactionsResponseRpnl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransactionsResponseRpnl
impl PartialEq for TransactionsResponseRpnl
impl StructuralPartialEq for TransactionsResponseRpnl