pub struct TransactionsResponseRpnlItems {
pub acctid: Option<String>,
pub amt: Option<String>,
pub conid: Option<String>,
pub cur: Option<String>,
pub date: Option<String>,
pub fx_rate: Option<i32>,
pub side: Option<TransactionsResponseRpnlItemsSide>,
}Fields
acctid: Option<String>Returns the account ID the trade transacted on.
amt: Option<String>Returns the amount gained or lost on the day.
conid: Option<String>Returns the contract ID of the transaction.
cur: Option<String>Specifies the currency of the realized value.
date: Option<String>Specifies the date for the transaction.
fx_rate: Option<i32>Returns the foreign exchnage rate.
side: Option<TransactionsResponseRpnlItemsSide>Determines if the day was a loss or gain * L - LOSS * G - GAIN