pub struct TransferRequestBody {
pub fp_order_id: Option<i32>,
pub req_id: Option<i32>,
}Fields
fp_order_id: Option<i32>Order identifier to monitor the order transmissions. Will be set to a valid id if and only if any transfers are present in the response. Otherwise, -1 is returned.
req_id: Option<i32>Request identifier to uniquely track a request.