pub struct TrsrvSecDefResponseSecdefDisplayRuleDisplayRuleStep {
pub decimal_digits: Option<i32>,
pub lower_edge: Option<f64>,
pub whole_digits: Option<i32>,
}Fields
decimal_digits: Option<i32>Displays the total number of digits used after the decimal value.
lower_edge: Option<f64>The lowerEdge display value to correspond to increment rules.
whole_digits: Option<i32>Displays valid display prices for before and after the decimal value.