pub struct WatchlistsResponse {
pub mid: Option<String>,
pub action: Option<String>,
pub data: Option<WatchlistsResponseData>,
}Expand description
Object containing a successful query for watchlists saved for the username in use in the current Web API session.
Fields
mid: Option<String>Internal use. Number of times endpoint has been visited during session.
action: Option<String>Internal use. Always has value ‘content’.
data: Option<WatchlistsResponseData>Contains the watchlist query results.