pub struct WatchlistsResponseData {
pub bulk_delete: Option<bool>,
pub scanners_only: Option<bool>,
pub show_scanners: Option<bool>,
pub user_lists: Option<Vec<WatchlistsResponseDataUserList>>,
}Expand description
Contains the watchlist query results.
Fields
bulk_delete: Option<bool>Indicates if username’s watchlists can be bulk-deleted.
scanners_only: Option<bool>Indicates if query results contain only market scanners.
show_scanners: Option<bool>Indicates if market scanners are included in query results.
user_lists: Option<Vec<WatchlistsResponseDataUserList>>Array of objects detailing the watchlists saved for the username in use in the current Web API session.