pub enum AllocationMethod {
A,
E,
N,
C,
P,
R,
S,
}Expand description
Interactive Brokers supports two forms of allocation methods. Allocation methods that have calculations completed by Interactive Brokers, and a set of allocation methods calculated by the user and then specified. IB-computed allocation methods:
A- Available EquityE- EqualN- Net Liquidation Value
User-specified allocation methods:
C- Cash QuantityP- PercentageR- RatiosS- Shares
Variants