pub enum CreateAlertResponse {
Ok(AlertCreationResponse),
BadRequest,
Unauthorized,
InternalServerError,
ServiceUnavailable,
Unknown,
}Expand description
Response types for createAlert
Variants
Ok(AlertCreationResponse)
200: An object containing valid accounts and the account properties regarding trading access. This endpoint is also used to confirm account validation.
BadRequest
400: bad request; body is empty
401: Invalid or expired access token
InternalServerError
500: Internal Server Error. Unable to process request if incoming values are not valid. For example operator is “abc” Or if modification request contains unmodified fields
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response