pub enum GetAlertDetailsResponse {
Ok(AlertDetails),
BadRequest,
Unauthorized,
InternalServerError,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getAlertDetails
Variants
Ok(AlertDetails)
200: An object containing all unique details of the specified alert.
BadRequest
400: bad request if orderId is empty or type is invalid
401: Invalid or expired access token
InternalServerError
500: orderId is not parsable; unable to process request
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response