pub enum GetGwApiV1ParticipatingBanksResponse {
Ok(GetParticipatingListResponse),
BadRequest,
InternalServerError,
Unknown,
}Expand description
Response types for get_gw_api_v1_participating_banks
Variants
Ok(GetParticipatingListResponse)
200: Returns the list of participating banks.
BadRequest
400: Returns a Problem detail instance representing a not found request.
InternalServerError
500: Unable to process request due to an Internal Error. Please try again later.
Unknown
default: Unknown response