pub enum GetPnlResponse {
Ok(PnlPartitionedResponse),
BadRequest,
Unauthorized,
ServiceUnavailable,
Unknown,
}Expand description
Response types for getPnl
Variants
Ok(PnlPartitionedResponse)
200: Refers to “updated PnL”. Holds a json object of key-value paired pnl details.
BadRequest
400: bad request; passed input cannot pass initial validation and detected right away
401: Invalid or expired access token
503: service is unavailable. For example if request takes more than 10s due to some internal service unavailability, request aborted and this status returned
Unknown
default: Unknown response