Reply200Response

Enum Reply200Response 

pub enum Reply200Response {
    OrderSubmitSuccess(OrderSubmitSuccess),
    OrderReplyMessage(OrderReplyMessage),
    OrderSubmitError(OrderSubmitError),
    OrderReplyNotFound(OrderReplyNotFound),
    AdvancedOrderReject(AdvancedOrderReject),
}

Variants



OrderSubmitSuccess(OrderSubmitSuccess)

A successful submission of one or more order tickets.



OrderReplyMessage(OrderReplyMessage)

An array containing objects that each deliver the order reply messages emitted against one order ticket in the submission request’s array. Indicies of the order reply message objects in this array correspond to the indicies of the order tickets in the submission request’s array.



OrderSubmitError(OrderSubmitError)

Indicates that the order reply message or submission was not accepted.



OrderReplyNotFound(OrderReplyNotFound)

Indicates that the order reply ID does not exist.



AdvancedOrderReject(AdvancedOrderReject)

Relates a message generated in response to the rejection of the submitted order ticket. In some cases, it may also present a mechanism to resubmit the same order following a prompted decision.

Implementations

Source

impl Reply200Response

pub fn order_submit_error(error: Option<String>) -> Self

Indicates that the order reply message or submission was not accepted.

pub fn order_reply_not_found(error: Option<String>) -> Self

Indicates that the order reply ID does not exist.

pub fn advanced_order_reject() -> Self

Relates a message generated in response to the rejection of the submitted order ticket. In some cases, it may also present a mechanism to resubmit the same order following a prompted decision.