pub enum SubAccountsAccountDatumKey {
AvailableEquity,
NetLiquidation,
}Expand description
Defines the value of the object
AvailableEquity- Indicates the value relates to the Available Equity held within the accountNetLiquidation- Indicates the value relates to the Net Liquidation held within the account
Variants