pub struct AccountAttributes {Show 24 fields
pub prepaid_crypto_p: Option<bool>,
pub prepaid_crypto_z: Option<bool>,
pub account_alias: Option<String>,
pub account_id: Option<String>,
pub account_status: Option<i32>,
pub account_title: Option<String>,
pub account_van: Option<String>,
pub acct_cust_type: Option<String>,
pub brokerage_access: Option<bool>,
pub business_type: Option<AccountAttributesBusinessType>,
pub category: Option<String>,
pub clearing_status: Option<AccountAttributesClearingStatus>,
pub covestor: Option<bool>,
pub currency: Option<String>,
pub desc: Option<String>,
pub display_name: Option<String>,
pub fa_client: Option<bool>,
pub ib_entity: Option<AccountAttributesIbEntity>,
pub id: Option<String>,
pub no_client_trading: Option<bool>,
pub parent: Option<AccountAttributesParent>,
pub track_virtual_fxportfolio: Option<bool>,
pub trading_type: Option<String>,
pub type: Option<String>,
}Fields
prepaid_crypto_p: Option<bool>Indicates whether account has a prepaid crypto segment (Crypto Plus) with PAXOS.
prepaid_crypto_z: Option<bool>Indicates whether account has a prepaid crypto segment (Crypto Plus) with ZEROHASH.
account_alias: Option<String>User-defined alias assigned to the account for easy identification.
account_id: Option<String>Indicates the identifying number for the account.
account_status: Option<i32>Unix epoch timestamp of account opening.
account_title: Option<String>A name assigned to the account, typically the account holder name or business entity.
account_van: Option<String>The account’s virtual account number, or otherwise its IB accountId if no VAN is set.
acct_cust_type: Option<String>Identifies the type of client with which the account is associated, such as an individual or LLC.
brokerage_access: Option<bool>Indicates whether account can receive live orders (do not mix with paper trading).
business_type: Option<AccountAttributesBusinessType>A descriptor of the nature of the account, reflecting the responsible group within IB.
category: Option<String>Designated account category. Only used in non-standard account structures.
clearing_status: Option<AccountAttributesClearingStatus>Status of the account with respect to clearing at IB. O is open, P pending, N new, A abandoned, C closed, R rejected.
covestor: Option<bool>Indicates a Covestor account.
currency: Option<String>Base currency of the account.
desc: Option<String>Internal human-readable description of the account.
display_name: Option<String>Displayed name of the account in UI. Will reflect either the accountId or accountAlias, if set.
fa_client: Option<bool>Indicates that the account is managed by a financial advisor.
ib_entity: Option<AccountAttributesIbEntity>IB business entity under which the account resides.
id: Option<String>The account’s IB accountId.
no_client_trading: Option<bool>Indicates that trading by the client is disabled in the account.
parent: Option<AccountAttributesParent>Describes account relations in partitioned or multiplexed (segemented) account structures.
track_virtual_fxportfolio: Option<bool>Indicates that virtual forex positions are tracked in the account.
trading_type: Option<String>Internal identifier used by IB to reflect the trading permissions of the account.
type: Option<String>Indicates whether the account exists in production, paper, or demo environments.