AccountSummaryResponse

Struct AccountSummaryResponse 

pub struct AccountSummaryResponse {
Show 17 fields pub sma: Option<f64>, pub account_type: Option<String>, pub accrued_interest: Option<f64>, pub available_funds: Option<f64>, pub balance: Option<f64>, pub buying_power: Option<f64>, pub cash_balances: Option<Vec<AccountSummaryResponseCashBalance>>, pub equity_with_loan_value: Option<f64>, pub excess_liquidity: Option<f64>, pub initial_margin: Option<f64>, pub maintenance_margin: Option<f64>, pub net_liquidation_value: Option<f64>, pub reg_tloan: Option<f64>, pub reg_tmargin: Option<f64>, pub securities_gvp: Option<f64>, pub status: Option<String>, pub total_cash_value: Option<f64>,
}
Successful return contianing an array of at-a-glance account details.

Fields

sma: Option<f64>

Simple Moving Average of the account.

account_type: Option<String>

Describes the unique account type. For standard individual accounts, an empty string is returned.

accrued_interest: Option<f64>

Accrued interest is the interest accruing on a security since the previous coupon date. If a security is sold between two payment dates, the buyer usually compensates the seller for the interest accrued, either within the price or as a separate payment.

available_funds: Option<f64>

The amount of equity you have available for trading. For both the Securities and Commodities segments, this is calculated as: Equity with Loan Value – Initial Margin.

balance: Option<f64>

Returns the total account balance.

buying_power: Option<f64>

Total buying power available for the account.

cash_balances: Option<Vec<AccountSummaryResponseCashBalance>>

An array containing balance information for all currencies held by the account.

equity_with_loan_value: Option<f64>

The basis for determining whether you have the necessary assets to either initiate or maintain security assets.

excess_liquidity: Option<f64>

The amount of cash in excess of the usual requirement in your account.

initial_margin: Option<f64>

The available initial margin for the account.

maintenance_margin: Option<f64>

The available maintenance margin for the account.

net_liquidation_value: Option<f64>

The basis for determining the price of the assets in your account.

reg_tloan: Option<f64>

The Federal Reserve Board regulation governing the amount of credit that broker dealers may extend to clients who borrow money to buy securities on margin.

reg_tmargin: Option<f64>

The initial margin requirements calculated under US Regulation T rules for both the securities and commodities segment of your account.

securities_gvp: Option<f64>

Absolute value of the Long Stock Value + Short Stock Value + Long Option Value + Short Option Value + Fund Value.

status: Option<String>

If the account is currently non-tradeable, a status message will be dispalyed.

total_cash_value: Option<f64>

Cash recognized at the time of trade + futures P&L. This value reflects real-time currency positions, including:

  • Trades executed directly through the FX market.
  • Trades executed as a result of automatic IB conversions, which occur when you trade a product in a non-base currency.
  • Trades deliberately executed to close non-base currency positions using the FXCONV destination.