pub struct AllocationGroupsDatum {
pub allocation_method: Option<AllocationMethod>,
pub name: Option<String>,
pub size: Option<i32>,
}Fields
allocation_method: Option<AllocationMethod>Interactive Brokers supports two forms of allocation methods. Allocation methods that have calculations completed by Interactive Brokers, and a set of allocation methods calculated by the user and then specified. IB-computed allocation methods:
A- Available EquityE- EqualN- Net Liquidation Value
User-specified allocation methods:
C- Cash QuantityP- PercentageR- RatiosS- Shares
name: Option<String>The name set for the given allocation group.
size: Option<i32>Represents the total number of sub-accounts within the group.