pub struct BrokerageSessionInitRequest {
pub compete: Option<bool>,
pub publish: Option<bool>,
}Fields
compete: Option<bool>Determines if other brokerage sessions should be disconnected to prioritize this connection.
publish: Option<bool>publish brokerage session token at the same time when brokerage session initialized. If set false, then session token should be published before calling init. Setting true is preferred way.