pub struct BrokerageSessionStatus {
pub mac: Option<String>,
pub authenticated: Option<bool>,
pub competing: Option<bool>,
pub connected: Option<bool>,
pub established: Option<bool>,
pub fail: Option<String>,
pub hardware_info: Option<String>,
pub message: Option<String>,
pub server_info: Option<BrokerageSessionStatusServerInfo>,
}Fields
mac: Option<String>Device MAC information.
authenticated: Option<bool>Returns whether your brokerage session is authenticated or not.
competing: Option<bool>Returns whether you have a competing brokerage session in another connection.
connected: Option<bool>Returns whether you are connected to the gateway or not.
established: Option<bool>Returns whether your brokerage session is fully established and ready to handle requests. Set to true when the login message is received from underlying brokerage infrastructure, indicating authentication is complete and account information is loaded.
fail: Option<String>Returns the reason for failing to retrieve authentication status.
hardware_info: Option<String>Client Portal use only.
message: Option<String>A message about your authenticate status if any.
server_info: Option<BrokerageSessionStatusServerInfo>Trait Implementations
Sourceimpl Clone for BrokerageSessionStatus
impl Clone for BrokerageSessionStatus
Sourcefn clone(&self) -> BrokerageSessionStatus
fn clone(&self) -> BrokerageSessionStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrokerageSessionStatus
impl Debug for BrokerageSessionStatus
Sourceimpl Default for BrokerageSessionStatus
impl Default for BrokerageSessionStatus
Sourceimpl<'de> Deserialize<'de> for BrokerageSessionStatus
impl<'de> Deserialize<'de> for BrokerageSessionStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrokerageSessionStatus
impl PartialEq for BrokerageSessionStatus
impl StructuralPartialEq for BrokerageSessionStatus