pub struct ComboPositionResponseComboPositionResponse {
pub description: Option<String>,
pub legs: Option<Vec<ComboPositionResponseComboPositionResponseLeg>>,
pub name: Option<String>,
pub positions: Option<Vec<IndividualComboPosition>>,
}Fields
description: Option<String>The ratio and conids included in the position.
legs: Option<Vec<ComboPositionResponseComboPositionResponseLeg>>List of the legs that make up a position.
name: Option<String>Internal identifier of a combination position.
positions: Option<Vec<IndividualComboPosition>>List of the positions that make up a combination.