pub struct ContractRules {Show 33 fields
pub algo_eligible: Option<bool>,
pub all_or_none_eligible: Option<bool>,
pub can_trade_acct_ids: Option<Vec<String>>,
pub cash_ccy: Option<String>,
pub cash_qty_incr: Option<i32>,
pub cash_size: Option<f64>,
pub cost_report: Option<bool>,
pub cqt_types: Option<Vec<ContractRulesCqtType>>,
pub default_size: Option<i32>,
pub display_size: Option<i32>,
pub error: Option<String>,
pub force_order_preview: Option<bool>,
pub fraq_int: Option<i32>,
pub fraq_types: Option<Vec<ContractRulesCqtType>>,
pub has_secondary: Option<bool>,
pub ib_algo_types: Option<Vec<ContractRulesIbAlgoType>>,
pub increment: Option<f64>,
pub increment_digits: Option<i32>,
pub increment_rules: Option<Vec<ContractRulesIncrementRule>>,
pub increment_type: Option<i32>,
pub limit_price: Option<f64>,
pub mod_types: Option<Vec<Value>>,
pub negative_capable: Option<bool>,
pub order_defaults: Option<ContractRulesOrderDefaults>,
pub order_origination: Option<String>,
pub order_types: Option<Vec<ContractRulesOrderType>>,
pub order_types_outside: Option<Vec<ContractRulesOrderTypesOutside>>,
pub preview: Option<bool>,
pub price_magnifier: Option<i32>,
pub size_increment: Option<i32>,
pub stop_price: Option<f64>,
pub tif_defaults: Option<ContractRulesTifDefaults>,
pub tif_types: Option<Vec<String>>,
}Expand description
detailed contract information
Fields
algo_eligible: Option<bool>Indicates if the contract can trade algos or not.
all_or_none_eligible: Option<bool>indicates all or non option is eligible for given contract.
can_trade_acct_ids: Option<Vec<String>>Indicates permitted accountIDs that may trade the contract.
cash_ccy: Option<String>Indicates base currency for the instrument.
cash_qty_incr: Option<i32>Indicates cash quantity increment rules.
cash_size: Option<f64>Default cash value quantity.
cost_report: Option<bool>Indicates whether or not a cost report has been requested (Client Portal only).
cqt_types: Option<Vec<ContractRulesCqtType>>Indicates accepted order types for use with cash quantity.
default_size: Option<i32>Default total quantity value for orders.
display_size: Option<i32>Standard display increment rule for the instrument.
error: Option<String>If rules information can not be received for any reason, it will be expressed here.
force_order_preview: Option<bool>Indicates if the order preview is forced upon the user before submission.
fraq_int: Option<i32>Indicates decimal places for fractional order size.
fraq_types: Option<Vec<ContractRulesCqtType>>Indicates permitted order types for use with fractional trading.
has_secondary: Option<bool>ib_algo_types: Option<Vec<ContractRulesIbAlgoType>>Indicates permitted algo types for use with the given contract.
increment: Option<f64>Minimum increment values for prices
increment_digits: Option<i32>Number of decimal places to indicate the increment value.
increment_rules: Option<Vec<ContractRulesIncrementRule>>Indicates increment rule values including lowerEdge and increment value.
increment_type: Option<i32>Indicates the type of increment style.
limit_price: Option<f64>Default limit price for the given contract.
mod_types: Option<Vec<Value>>Lists the available order types supported when modifying the order.
negative_capable: Option<bool>Indicates if the value of the contract can be negative (true) or if it is always positive (false).
order_defaults: Option<ContractRulesOrderDefaults>Indicates default order type for the given security type.
order_origination: Option<String>Order origin designation for US securities options and Options Clearing Corporation
order_types: Option<Vec<ContractRulesOrderType>>Indicates permitted order types for use with standard quantity trading.
order_types_outside: Option<Vec<ContractRulesOrderTypesOutside>>Indicates permitted order types for use outside of regular trading hours.
preview: Option<bool>Indicates if the order preview is required (for client portal only)
price_magnifier: Option<i32>Signifies the magnifier of a given contract. This is separate from the price multiplier, and will typically return ‘null’
size_increment: Option<i32>Indicates quantity increase for the contract.
stop_price: Option<f64>Default stop price for the given contract.
tif_defaults: Option<ContractRulesTifDefaults>Object containing details about your TIF value defaults. These defaults can be viewed and modified in TWS’s within the Global Configuration.
tif_types: Option<Vec<String>>Indicates allowed tif types supported for the contract.