ContractRulesIncrementRule

Struct ContractRulesIncrementRule 

pub struct ContractRulesIncrementRule {
    pub increment: Option<f64>,
    pub lower_edge: Option<f64>,
}

Fields

increment: Option<f64>

The price of the instrument must be submitted as a mulitple of the increment value.

lower_edge: Option<f64>

If the current mark price of the instrument is at or above the lower edge, the given increment value is used for order prices.