pub struct GetAllFyisRequestQuery {
pub max: i32,
pub include: Option<Value>,
pub exclude: Option<Value>,
pub id: Option<Value>,
}Fields
max: i32Specify the maximum number of notifications to receive. Can request a maximum of 10 notifications.
- Example:
10i32
include: Option<Value>Include only the specified typecode notifications in the request.
exclude: Option<Value>Include all subscribed notifications except the typecodes passed here.
id: Option<Value>if more required, notifcationId of last notification should be used to define next batch border