pub struct GetAllocationGroupsRequest {}Expand description
Retrieves a list of all of the advisor’s allocation groups. This describes the name of the allocation group, number of subaccounts within the group, and the method in use for the group. This endpoint is only supported for Financial Advisors and IBroker Accounts.
Implementations
Sourceimpl GetAllocationGroupsRequest
impl GetAllocationGroupsRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetAllocationGroupsResponse>
pub async fn parse_response( req: Response, ) -> Result<GetAllocationGroupsResponse>
Parse the HTTP response into the response enum.