pub struct GetAllocationPresetsRequest {}Expand description
Retrieve the preset behavior for allocation groups for specific events. This endpoint is only supported for Financial Advisors and IBroker Accounts.
Implementations
Sourceimpl GetAllocationPresetsRequest
impl GetAllocationPresetsRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetAllocationPresetsResponse>
pub async fn parse_response( req: Response, ) -> Result<GetAllocationPresetsResponse>
Parse the HTTP response into the response enum.