pub struct GetConidsByExchangeRequest {
pub query: GetConidsByExchangeRequestQuery,
}Expand description
Send out a request to retrieve all contracts made available on a requested exchange. This returns all contracts that are tradable on the exchange, even those that are not using the exchange as their primary listing.
Fields
query: GetConidsByExchangeRequestQueryImplementations
Sourceimpl GetConidsByExchangeRequest
impl GetConidsByExchangeRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetConidsByExchangeResponse>
pub async fn parse_response( req: Response, ) -> Result<GetConidsByExchangeResponse>
Parse the HTTP response into the response enum.