pub struct GetMdSnapshotRequest {
pub query: GetMdSnapshotRequestQuery,
}Expand description
Get Market Data for the given conid(s). A pre-flight request must be made prior to ever receiving data. For some fields, it may take more than a few moments to receive information. See response fields for a list of available fields that can be request via fields argument. The endpoint /iserver/accounts must be called prior to /iserver/marketdata/snapshot. For derivative contracts the endpoint /iserver/secdef/search must be called first.
Fields
query: GetMdSnapshotRequestQueryImplementations
Sourceimpl GetMdSnapshotRequest
impl GetMdSnapshotRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetMdSnapshotResponse>
pub async fn parse_response(req: Response) -> Result<GetMdSnapshotResponse>
Parse the HTTP response into the response enum.