pub struct GetPnlRequest {}Expand description
Returns updated profit and loss values for the selected account. Initial request will return an empty array in the upnl object.
Implementations
Sourceimpl GetPnlRequest
impl GetPnlRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetPnlResponse>
pub async fn parse_response(req: Response) -> Result<GetPnlResponse>
Parse the HTTP response into the response enum.