pub struct GetSessionTokenRequest {}Expand description
If the gateway has not received any requests for several minutes an open session will automatically timeout. The tickle endpoint pings the server to prevent the session from ending. It is expected to call this endpoint approximately every 60 seconds to maintain the connection to the brokerage session.
Implementations
Sourceimpl GetSessionTokenRequest
impl GetSessionTokenRequest
Sourcepub async fn parse_response(req: Response) -> Result<GetSessionTokenResponse>
pub async fn parse_response(req: Response) -> Result<GetSessionTokenResponse>
Parse the HTTP response into the response enum.