GetSingleAllocationGroupRequest

Struct GetSingleAllocationGroupRequest 

pub struct GetSingleAllocationGroupRequest {
    pub body: NameRequestBody,
}
Retrieves the configuration of a single account group. This describes the name of the allocation group, the specific accounts contained in the group, and the allocation method in use along with any relevant quantities. This endpoint is only supported for Financial Advisors and IBroker Accounts.

Fields

body: NameRequestBody

Implementations

Source

impl GetSingleAllocationGroupRequest

pub async fn parse_response( req: Response, ) -> Result<GetSingleAllocationGroupResponse>

Parse the HTTP response into the response enum.