pub struct GetSingleAllocationGroupRequest {
pub body: NameRequestBody,
}Expand description
Retrieves the configuration of a single account group. This describes the name of the allocation group, the specific accounts contained in the group, and the allocation method in use along with any relevant quantities. This endpoint is only supported for Financial Advisors and IBroker Accounts.
Fields
body: NameRequestBodyImplementations
Sourceimpl GetSingleAllocationGroupRequest
impl GetSingleAllocationGroupRequest
Sourcepub async fn parse_response(
req: Response,
) -> Result<GetSingleAllocationGroupResponse>
pub async fn parse_response( req: Response, ) -> Result<GetSingleAllocationGroupResponse>
Parse the HTTP response into the response enum.