pub struct IserverScannerParamsLocationTree {
pub display_name: Option<String>,
pub locations: Option<Vec<IserverScannerParamsLocationTreeLocation>>,
pub type: Option<String>,
}Fields
display_name: Option<String>Returns the overarching instrument type to designate the location.
locations: Option<Vec<IserverScannerParamsLocationTreeLocation>>type: Option<String>Returns the code value of the market scanner instrument type value.