pub struct IserverScannerRunRequest {
pub filter: Option<Vec<IserverScannerRunRequestFilter>>,
pub instrument: Option<String>,
pub location: Option<String>,
pub type: Option<String>,
}Fields
filter: Option<Vec<IserverScannerRunRequestFilter>>Contains any additional filters that should apply to response.
instrument: Option<String>Instrument type as the target of the market scanner request. Found in the “instrument_list” section of the /iserver/scanner/params response.
location: Option<String>Location value the market scanner is searching through. Based on the “location_tree” section of the /iserver/scanner/params response.
type: Option<String>Scanner value the market scanner is sorted by. Based on the “scan_type_list” section of the /iserver/scanner/params response.