pub struct LiveOrdersResponseOrder {Show 35 fields
pub account: Option<String>,
pub acct: Option<String>,
pub avg_price: Option<String>,
pub bg_color: Option<String>,
pub cash_ccy: Option<String>,
pub company_name: Option<String>,
pub conid: Option<String>,
pub conidex: Option<String>,
pub description1: Option<String>,
pub description2: Option<String>,
pub exchange: Option<String>,
pub fg_color: Option<String>,
pub filled_quantity: Option<String>,
pub is_event_trading: Option<AlertActivationRequestAlertActive>,
pub last_execution_time: Option<String>,
pub last_execution_time_r: Option<String>,
pub listing_exchange: Option<String>,
pub order_desc: Option<String>,
pub order_id: Option<i32>,
pub order_type: Option<String>,
pub order_cancellation_by_system_reason: Option<String>,
pub order_ccp_status: Option<String>,
pub orig_order_type: Option<String>,
pub price: Option<String>,
pub remaining_quantity: Option<String>,
pub sec_type: Option<String>,
pub side: Option<String>,
pub size_and_fills: Option<String>,
pub status: Option<OrderStatusOrderStatus>,
pub supports_tax_opt: Option<AlertActivationRequestAlertActive>,
pub tax_optimizer_id: Option<String>,
pub ticker: Option<String>,
pub time_in_force: Option<String>,
pub total_cash_size: Option<String>,
pub total_size: Option<String>,
}Expand description
Object representing one order.
Fields
account: Option<String>IB account ID to which the order was placed.
acct: Option<String>IB account ID to which the order was placed.
avg_price: Option<String>Average price of fills against the order, if any.
bg_color: Option<String>Internal use. IB’s UI background color in hex.
cash_ccy: Option<String>Currency of the order ticket’s Cash Quantity, if applicable.
company_name: Option<String>Name of business associated with instrument, or otherwise description of instrument.
conid: Option<String>Contract ID of the order’s instrument.
conidex: Option<String>Contract ID and routing destination in format 123456@EXCHANGE.
description1: Option<String>Descriptive text, or additional details that specific the instrument.
description2: Option<String>Only present for derivatives. Shows Expiry, Strike, Right, And Exchange information.
exchange: Option<String>Routing destination of the order ticket.
fg_color: Option<String>Internal use. IB’s UI foreground color in hex.
filled_quantity: Option<String>Quantity filled in units of the instrument.
is_event_trading: Option<AlertActivationRequestAlertActive>Indicates whether the order ticket is an Event Trading order.
last_execution_time: Option<String>Time of last execution against the order in format YYMMDDhhmmss.
last_execution_time_r: Option<String>Unix timestamp of the last execution against the order.
listing_exchange: Option<String>Exchange on which the instrument is listed.
order_desc: Option<String>Human-readable shorthand rendering of the order ticket.
order_id: Option<i32>IB-assigned order identifier.
order_type: Option<String>Order type of a working order ticket.
order_cancellation_by_system_reason: Option<String>Only present for Cancelled orders. Provides the reason for order to have been cancelled or rejected by the system.
order_ccp_status: Option<String>IB internal order status.
orig_order_type: Option<String>Order type of a filled order.
price: Option<String>Price of the order, if applicable to the order type.
remaining_quantity: Option<String>Quantity remaining to be filled in units of the instrument.
sec_type: Option<String>Asset class of the instrument.
side: Option<String>Side of the order.
size_and_fills: Option<String>Human-readable shorthand rendering of the filled and total quantities of the order.
status: Option<OrderStatusOrderStatus>Status of the order ticket.
supports_tax_opt: Option<AlertActivationRequestAlertActive>Indicates whether the order is supported by IB’s Tax Optimization tool.
tax_optimizer_id: Option<String>Tax Optimizer id, identifies set of tax lots selected, for gains and losses management.
ticker: Option<String>Symbol or base product code of the instrument.
time_in_force: Option<String>Time of force of the order.
total_cash_size: Option<String>Total size of a cash quantity order.
total_size: Option<String>Total size of an order in the instrument’s units.