pub struct ModelPresetsResponse {
pub avoid_negative_cash_in_independent: Option<bool>,
pub close_divest_independent_position: Option<bool>,
pub fully_invest_existing_long_positions: Option<bool>,
pub keep_model_open: Option<bool>,
pub prefer_cross_with_independent: Option<bool>,
pub prefer_transfer_from_independent: Option<bool>,
pub req_id: Option<i32>,
pub round_allocation_quantity_to_exchange_board_lot: Option<bool>,
pub subscription_status: Option<i32>,
pub use_non_base_ccy: Option<bool>,
pub use_tolerance_range: Option<bool>,
}Fields
avoid_negative_cash_in_independent: Option<bool>Avoid negative offsetting cash in Independent
close_divest_independent_position: Option<bool>Close out the full position while divesting.
fully_invest_existing_long_positions: Option<bool>Use the maximum avialble funds to increase long positions.
keep_model_open: Option<bool>Keep model open for fully divested accounts.
prefer_cross_with_independent: Option<bool>Transfer positions to Independent instead of liquidating.
prefer_transfer_from_independent: Option<bool>Transfer positions from Independent structure when possible.
req_id: Option<i32>Request identifier to uniquely track a request.
round_allocation_quantity_to_exchange_board_lot: Option<bool>Determine if allocation quantities should be handled by lot size.
subscription_status: Option<i32>Describes if the model is in polling mode.
use_non_base_ccy: Option<bool>Use non-base balances when available.
use_tolerance_range: Option<bool>Designate of tolerance ranges should be used for rebalancing.