OrderStatus

Struct OrderStatus 

pub struct OrderStatus {
Show 42 fields pub account: Option<String>, pub alert_active: Option<AlertActivationRequestAlertActive>, pub allowed_duplicate_opposite: Option<bool>, pub available_chart_periods: Option<String>, pub average_price: Option<String>, pub bg_color: Option<String>, pub cannot_cancel_order: Option<bool>, pub child_order_type: Option<OrderStatusChildOrderType>, pub company_name: Option<String>, pub conid: Option<i32>, pub conidex: Option<String>, pub contract_description_1: Option<String>, pub cum_fill: Option<String>, pub currency: Option<String>, pub deactivate_order: Option<bool>, pub editable_fields: Option<String>, pub exit_strategy_chart_description: Option<String>, pub exit_strategy_display_price: Option<String>, pub exit_strategy_tool_availability: Option<String>, pub fg_color: Option<String>, pub listing_exchange: Option<String>, pub option_acct: Option<String>, pub order_ccp_status: Option<String>, pub order_clearing_account: Option<String>, pub order_description: Option<String>, pub order_description_with_contract: Option<String>, pub order_id: Option<i32>, pub order_not_editable: Option<bool>, pub order_status: Option<OrderStatusOrderStatus>, pub order_status_description: Option<String>, pub order_time: Option<String>, pub order_type: Option<String>, pub request_id: Option<String>, pub sec_type: Option<OrderStatusSecType>, pub server_id: Option<String>, pub side: Option<Side>, pub size: Option<String>, pub size_and_fills: Option<String>, pub sub_type: Option<String>, pub symbol: Option<String>, pub tif: Option<OrderStatusTif>, pub total_size: Option<String>,
}
Object containing information about the status of an order ticket.

Fields

account: Option<String>

The account receiving executions against this order ticket.

alert_active: Option<AlertActivationRequestAlertActive>

Indicates that an alert is active for the order ticket.

allowed_duplicate_opposite: Option<bool>

Indicates whether an identical order on the opposite side can be placed.

available_chart_periods: Option<String>

Internal use. Indicates chart periods available for the instrument.

average_price: Option<String>

Average price of fills against the order, if any.

bg_color: Option<String>

Internal use. IB’s UI background color in hex.

cannot_cancel_order: Option<bool>

Indicates whether the order ticket can be cancelled.

child_order_type: Option<OrderStatusChildOrderType>

Indicates if the order ticket is hedged, and if so, in what way. 0 = No hedge, A = Attached child hedge order, B = Beta/portfolio hedge

company_name: Option<String>

Name of the company or asset associated with the instrument.

conid: Option<i32>

Contract ID of the order’s instrument.

conidex: Option<String>

Contract ID and routing destination in format 123456@EXCHANGE.

contract_description_1: Option<String>

Human-readable description of the order’s instrument.

cum_fill: Option<String>

Cumulative filled quantity of the instrument against the order ticket.

currency: Option<String>

The currency in which the instrument trades and executions are conducted.

deactivate_order: Option<bool>

Indicates whether the order ticket can be deactivated.

editable_fields: Option<String>

Indicates which fields of the order ticket can be modified currently.

exit_strategy_chart_description: Option<String>

Internal use. A string describing an active Client Portal exit strategy, or the result of its execution.

exit_strategy_display_price: Option<String>

Internal use. The UI-displayed price associated with a Client Portal exist strategy.

exit_strategy_tool_availability: Option<String>

Internal use. Indicates the availability of Client Portal exit strategy tool for the order.

fg_color: Option<String>

Internal use. IB’s UI foreground color in hex.

listing_exchange: Option<String>

Primary listing exchange of the order ticket’s instrument.

option_acct: Option<String>

Internal use only.

order_ccp_status: Option<String>

IB internal order status.

order_clearing_account: Option<String>

The IB account to which the order ticket clears.

order_description: Option<String>

Human-readable description of the status or current result of the order ticket, meant for UI presentation.

order_description_with_contract: Option<String>

Human-readable description of the status or current result of the order ticket, meant for UI presentation. Includes instrument name.

order_id: Option<i32>

The IB-assigned order identifier of the order, as provided in the request path.

order_not_editable: Option<bool>

Indicates whether the order ticket can be modified.

order_status: Option<OrderStatusOrderStatus>

Status of the order ticket.

order_status_description: Option<String>

Human-readable rendering of the order’s status meant for presentation in UI.

order_time: Option<String>

Time of the order’s submission in format YYMMDDhhmmss.

order_type: Option<String>

The order’s IB order type.

request_id: Option<String>

Internal use only. IB-assigned identifier for the status request.

sec_type: Option<OrderStatusSecType>

IB asset class identifier.

server_id: Option<String>

IB-assigned meta-identifier used to associate rejected and resubmitted orders following Server Prompts.

side: Option<Side>

Side of the order ticket.

size: Option<String>

Remaining unfilled size of the order ticket. Will reflect 0.0 if order is filled in full, cancelled, or otherwise resolved and no longer working.

size_and_fills: Option<String>

A string reflecting the cumulative fills and total size of the order.

sub_type: Option<String>

Internal use only.

symbol: Option<String>

Symbol of the order ticket’s instrument.

tif: Option<OrderStatusTif>

Time in force of the order ticket.

total_size: Option<String>

The total size of the order ticket.