pub struct QueryWithdrawableFunds {
pub account_id: String,
pub bank_account_number: Option<String>,
pub bank_instruction_name: Option<String>,
pub bank_routing_number: Option<String>,
pub client_instruction_id: f64,
pub currency: String,
}Fields
account_id: String- Example:
"U399192".to_string()
bank_account_number: Option<String>If bankAccountNumber is provided then bankRoutingNumber is also required, cannot be passed with bankInstructionName
- Example:
Some("9876543210".to_string())
bank_instruction_name: Option<String>bankInstructionName cannot be passed with (bankAccountNumber or bankRoutingNumber)
- Example:
Some("test".to_string())
bank_routing_number: Option<String>If bankRoutingNumber is provided then bankAccountNumber is also required, cannot be passed with bankInstructionName
- Example:
Some("122199983".to_string())
client_instruction_id: f64- Example:
1012983.0
currency: String- Example:
"USD".to_string()