Rule200Response

Struct Rule200Response 

pub struct Rule200Response {
Show 27 fields pub allow_sell_long: Option<bool>, pub category: Option<String>, pub cfi_code: Option<String>, pub classifier: Option<String>, pub company_name: Option<String>, pub con_id: Option<i32>, pub contract_clarification_type: Option<String>, pub contract_month: Option<String>, pub currency: Option<String>, pub cusip: Option<String>, pub exchange: Option<String>, pub expiry_full: Option<String>, pub industry: Option<String>, pub instrument_type: Option<String>, pub is_zero_commission_security: Option<bool>, pub local_symbol: Option<String>, pub maturity_date: Option<String>, pub multiplier: Option<String>, pub r_t_h: Option<bool>, pub rules: Option<ContractRules>, pub smart_available: Option<bool>, pub symbol: Option<String>, pub text: Option<String>, pub trading_class: Option<String>, pub underlying_con_id: Option<i32>, pub underlying_issuer: Option<String>, pub valid_exchanges: Option<String>,
}

Fields

allow_sell_long: Option<bool>

Allowed to sell shares you own.

category: Option<String>

Indicates the industry category of the instrument.

cfi_code: Option<String>

Classification of Financial Instrument codes

classifier: Option<String>company_name: Option<String>

Indicates the name of the company or index.

con_id: Option<i32>

Indicates the contract identifier of the given contract.

contract_clarification_type: Option<String>contract_month: Option<String>

Indicates the year and month the contract expires.

currency: Option<String>

Base currency contract is traded in.

cusip: Option<String>

Returns the CUSIP for the given instrument. Only used in BOND trading.

exchange: Option<String>

Indicates the primary exchange for which the contract can be traded.

expiry_full: Option<String>

Returns the expiration month of the contract.

industry: Option<String>

Specific group of companies or businesses.

instrument_type: Option<String>

Asset class of the instrument.

is_zero_commission_security: Option<bool>

Indicates if the contract supports zero commission trading.

local_symbol: Option<String>

Contract’s symbol from primary exchange. For options it is the OCC symbol.

maturity_date: Option<String>

Indicates the final maturity date of the given contract.

multiplier: Option<String>

Indicates the multiplier of the contract.

r_t_h: Option<bool>

Indicates if the contract can be traded outside regular trading hours or not.

rules: Option<ContractRules>

detailed contract information

smart_available: Option<bool>

Indicates if the contract can be smart routed or not.

symbol: Option<String>

Underlying symbol

text: Option<String>

Indicates the display name of the contract, as shown with Client Portal.

trading_class: Option<String>

Designated trading class of the contract.

underlying_con_id: Option<i32>

Underlying contract identifier for the requested contract.

underlying_issuer: Option<String>

Indicates the issuer of the underlying.

valid_exchanges: Option<String>

Comma separated list of support exchanges or trading venues.