SummaryMarketValueResponseCurrency

Struct SummaryMarketValueResponseCurrency 

pub struct SummaryMarketValueResponseCurrency {
Show 24 fields pub cryptocurrency: Option<String>, pub exchange_rate: Option<String>, pub govt_bonds: Option<String>, pub mtd_interest: Option<String>, pub notional_cfd: Option<String>, pub bonds: Option<String>, pub cfd: Option<String>, pub commodity: Option<String>, pub dividends_receivable: Option<String>, pub funds: Option<String>, pub future_options: Option<String>, pub futures: Option<String>, pub issuer_option: Option<String>, pub money_market: Option<String>, pub mutual_funds: Option<String>, pub net_liquidation: Option<String>, pub options: Option<String>, pub realized_pnl: Option<String>, pub settled_cash: Option<String>, pub stock: Option<String>, pub t_bills: Option<String>, pub total_cash: Option<String>, pub unrealized_pnl: Option<String>, pub warrants: Option<String>,
}
Returns an object containing market value details of the currency and positions held using that currency.

Fields

cryptocurrency: Option<String>

Total cash value of Cryptocurrencies held.

exchange_rate: Option<String>

Exchange rate of the labeled currency to the base currency.

govt_bonds: Option<String>

Total cash value of goverment bonds held.

mtd_interest: Option<String>

Total Month-to-date interest.

notional_cfd: Option<String>

Total cash value of notional CFDs held.

bonds: Option<String>

Total cash value of bonds held.

cfd: Option<String>

Total cash value of CFDs held.

commodity: Option<String>

Total cash value of commodities held.

dividends_receivable: Option<String>

Total cash value of receivable dividends.

funds: Option<String>

Total cash value of funds held.

future_options: Option<String>

Total cash value of future options held.

futures: Option<String>

Total cash value of futures held.

issuer_option: Option<String>

Total cash value of issuer options held.

money_market: Option<String>

Total cash value of money market securities held.

mutual_funds: Option<String>

Total cash value of mutual funds held.

net_liquidation: Option<String>

Total cash value of your net liquidty.

options: Option<String>

Total cash value of options held.

realized_pnl: Option<String>

Total daily realized profit and loss.

settled_cash: Option<String>

Cash recognized at the time of settlement minus the purchases at time of trade, commissions, taxes, and fees.

stock: Option<String>

Total cash value of stocks held.

t_bills: Option<String>

Total cash value of t-bill bonds held.

total_cash: Option<String>

Lists the total cash held for the given currency.

unrealized_pnl: Option<String>

Total daily unrealized profit and loss.

warrants: Option<String>

Total cash value of warrants held.