pub struct TrsrvSecDefResponseSecdef {Show 27 fields
pub all_exchanges: Option<String>,
pub asset_class: Option<String>,
pub chinese_name: Option<String>,
pub conid: Option<i32>,
pub country_code: Option<String>,
pub currency: Option<String>,
pub display_rule: Option<Vec<TrsrvSecDefResponseSecdefDisplayRule>>,
pub expiry: Option<String>,
pub full_name: Option<String>,
pub group: Option<String>,
pub has_options: Option<bool>,
pub increment_rules: Option<Vec<TrsrvSecDefResponseSecdefIncrementRule>>,
pub is_event_contract: Option<bool>,
pub is_us: Option<bool>,
pub last_trading_day: Option<String>,
pub listing_exchange: Option<String>,
pub multiplier: Option<f64>,
pub name: Option<String>,
pub page_size: Option<i32>,
pub put_or_call: Option<String>,
pub sector: Option<String>,
pub sector_group: Option<String>,
pub strike: Option<String>,
pub ticker: Option<String>,
pub time: Option<i32>,
pub type: Option<String>,
pub und_conid: Option<i32>,
}Fields
all_exchanges: Option<String>A series of exchanges the given symbol can trade on.
asset_class: Option<String>The asset class or security type of the contract.
chinese_name: Option<String>The Chinese characters for the symbol.
conid: Option<i32>The conID
country_code: Option<String>The country code the contract is traded on.
currency: Option<String>The traded currency for the contract.
display_rule: Option<Vec<TrsrvSecDefResponseSecdefDisplayRule>>Returns rules regarding incrementation for order placement. Not functional for all exchanges. Please see /iserver/contract/rules for more accurate rule details.
expiry: Option<String>The expiry of the contract. Returns null for non-expiry instruments.
full_name: Option<String>Returns symbol name for requested contract.
group: Option<String>The group or industry the contract is affilated with.
has_options: Option<bool>contract has tradable options contracts.
increment_rules: Option<Vec<TrsrvSecDefResponseSecdefIncrementRule>>Indicates increment rule values including lowerEdge and increment value.
is_event_contract: Option<bool>The contract is an event contract or not.
is_us: Option<bool>The contract is US based or not.
last_trading_day: Option<String>The last trading day of the contract.
listing_exchange: Option<String>The primary or listing exchange the contract is hosted on.
multiplier: Option<f64>The contract multiplier.
name: Option<String>The company name.
page_size: Option<i32>Returns the content size of the request.
put_or_call: Option<String>a Put or Call option.
sector: Option<String>The contract’s sector.
sector_group: Option<String>The sector’s group.
strike: Option<String>The strike of the contract.
ticker: Option<String>The ticker symbol of the traded contract.
time: Option<i32>Amount of time in ms to generate the data.
type: Option<String>Stock type.
und_conid: Option<i32>The contract’s underlyer.