pub type OrderReplyMessage = Vec<OrderReplyMessageOrderReplyMessage>;Expand description
An array containing objects that each deliver the order reply messages emitted against one order ticket in the submission request’s array. Indicies of the order reply message objects in this array correspond to the indicies of the order tickets in the submission request’s array.
Aliased Type
pub struct OrderReplyMessage { /* private fields */ }